# 7 "parsing_cocci/lexer_cocci.mll"
 
open Parser_cocci_menhir
module D = Data
module Ast = Ast_cocci
module Ast0 = Ast0_cocci
module P = Parse_aux
module FC = Flag_parsing_cocci
exception Lexical of string
let tok = Lexing.lexeme

let line = ref 1
let file = ref ""
let logical_line = ref 0

(* ---------------------------------------------------------------------- *)
(* control codes *)

(* Defined in data.ml
type line_type = MINUS | OPTMINUS | PLUS | CONTEXT | OPT
*)

let current_line_type = ref (D.CONTEXT,!line,!logical_line)

let prev_plus = ref false
let line_start = ref 0 (* offset of the beginning of the line *)
let get_current_line_type lexbuf =
  let (c,l,ll) = !current_line_type in
  let lex_start = Lexing.lexeme_start lexbuf in
  let preceeding_spaces =
    if !line_start < 0 then 0 else lex_start - !line_start in
  (*line_start := -1;*)
  prev_plus := (c = D.PLUS) || (c = D.PLUSPLUS);
  (c,l,ll,ll,lex_start,preceeding_spaces,[],[],[],"")
let current_line_started = ref false
let col_zero = ref true

let contextify (c,l,ll,lle,lex_start,preceeding_spaces,bef,aft,pos,ws) =
  (D.CONTEXT,l,ll,lle,lex_start,preceeding_spaces,bef,aft,pos,ws)

let reset_line lexbuf =
  line := !line + 1;
  current_line_type := (D.CONTEXT,!line,!logical_line);
  current_line_started := false;
  (if not(!Data.in_meta || !Data.in_rule_name) then col_zero := true);
  line_start := Lexing.lexeme_start lexbuf + 1

let started_line = ref (-1)

let start_line seen_char =
  current_line_started := true;
  col_zero := false;
  (if seen_char && not(!line = !started_line)
  then
    begin
      started_line := !line;
      logical_line := !logical_line + 1
    end)

let pass_zero _ = col_zero := false

let lexerr s1 s2 = raise (Lexical (Printf.sprintf "%s%s" s1 s2))

let opt_reverse_token token =
  if !FC.interpret_inverted
  then match token with
         D.MINUS        -> D.PLUSPLUS  (* maybe too liberal *)
       | D.OPTMINUS     -> lexerr "cannot invert token ?- (an optional minus line), which is needed for reversing the patch" ""
       | D.PLUS         -> D.MINUS
       | D.PLUSPLUS     -> D.MINUS (* may not be sufficient *)
       | _              -> token
  else token

let add_current_line_type x =
  match (opt_reverse_token x,!current_line_type) with
    (D.MINUS,(D.CONTEXT,ln,lln))  ->
      current_line_type := (D.MINUS,ln,lln)
  | (D.MINUS,(D.OPT,ln,lln))      ->
      current_line_type := (D.OPTMINUS,ln,lln)
  | (D.PLUS,(D.CONTEXT,ln,lln))   ->
      current_line_type := (D.PLUS,ln,lln)
  | (D.PLUSPLUS,(D.CONTEXT,ln,lln))   ->
      current_line_type := (D.PLUSPLUS,ln,lln)
  | (D.OPT,(D.CONTEXT,ln,lln))    ->
      current_line_type := (D.OPT,ln,lln)
  | _ -> lexerr "invalid control character combination" ""

let check_minus_context_linetype s =
  match !current_line_type with
    (D.PLUS,_,_) | (D.PLUSPLUS,_,_) -> lexerr "invalid in a + context: " s
  | _ -> ()

let check_context_linetype s =
  match !current_line_type with
    (D.CONTEXT,_,_) -> ()
  | _ -> lexerr "invalid in a nonempty context: " s

let check_plus_linetype s =
  match !current_line_type with
    (D.PLUS,_,_) | (D.PLUSPLUS,_,_) -> ()
  | _ -> lexerr "invalid in a non + context: " s

let check_arity_context_linetype s =
  match !current_line_type with
    (D.CONTEXT,_,_) | (D.PLUS,_,_) | (D.PLUSPLUS,_,_)
  | (D.OPT,_,_) -> ()
  | _ -> lexerr "invalid in a nonempty context: " s

let check_comment s =
  if not !current_line_started
  then lexerr "+ expected at the beginning of the line" s

let process_include start finish str =
  (match !current_line_type with
    (D.PLUS,_,_) | (D.PLUSPLUS,_,_) ->
      (try
	let _ = Str.search_forward (Str.regexp "\\.\\.\\.") str start in
	lexerr "... not allowed in + include" ""
      with Not_found -> ())
  | _ -> ());
  String.sub str (start + 1) (finish - start - 1)

(* ---------------------------------------------------------------------- *)
type pm = PATCH | MATCH | UNKNOWN

let pm = ref UNKNOWN

let patch_or_match = function
    PATCH ->
      if not !D.ignore_patch_or_match
      then
	(match !pm with
	  MATCH ->
	    lexerr "- or + not allowed in the first column for a match" ""
	| PATCH -> ()
	| UNKNOWN -> Flag.sgrep_mode2 := false; pm := PATCH)
  | MATCH ->
      if not !D.ignore_patch_or_match
      then
	(match !pm with
	  PATCH -> lexerr "* not allowed in the first column for a patch" ""
	| MATCH -> ()
	| UNKNOWN -> Flag.sgrep_mode2 := true; pm := MATCH)
  | _ -> failwith "unexpected argument"

(* ---------------------------------------------------------------------- *)
(* identifiers, including metavariables *)

let metavariables = (Hashtbl.create(100) : (string, D.clt -> token) Hashtbl.t)

let all_metavariables =
  (Hashtbl.create(100) : (string,(string * (D.clt -> token)) list) Hashtbl.t)

let type_names = (Hashtbl.create(100) : (string, D.clt -> token) Hashtbl.t)

let attr_names = (Hashtbl.create(100) : (string, D.clt -> token) Hashtbl.t)

let declarer_names = (Hashtbl.create(100) : (string, D.clt -> token) Hashtbl.t)

let iterator_names = (Hashtbl.create(100) : (string, D.clt -> token) Hashtbl.t)

let symbol_names = (Hashtbl.create(15) : (string, D.clt -> token) Hashtbl.t)

let rule_names = (Hashtbl.create(100) : (string, unit) Hashtbl.t)

let check_var s linetype =
  let fail _ =
    if (!Data.in_prolog || !Data.in_rule_name) &&
      Str.string_match (Str.regexp "<.*>") s 0
    then TPathIsoFile s
    else
      try (Hashtbl.find metavariables s) linetype
      with Not_found ->
	(try (Hashtbl.find type_names s) linetype
	with Not_found ->
	  (try (Hashtbl.find attr_names s) linetype
	  with Not_found ->
	    (try (Hashtbl.find declarer_names s) linetype
	    with Not_found ->
	      (try (Hashtbl.find iterator_names s) linetype
	      with Not_found ->
		(try (Hashtbl.find symbol_names s) linetype
		with Not_found ->
                  TIdent (s,linetype)))))) in
  if !Data.in_meta || !Data.in_rule_name
  then (try Hashtbl.find rule_names s; TRuleName s with Not_found -> fail())
  else fail()

let id_tokens lexbuf =
  let s = tok lexbuf in
  let linetype = get_current_line_type lexbuf in
  let in_rule_name = !Data.in_rule_name in
  let in_meta = !Data.in_meta && not !Data.saw_struct in
  let in_iso = !Data.in_iso in
  let in_prolog = !Data.in_prolog in
  (if s = "identifer" && in_meta
  then Common.pr2 "Warning: should identifer be identifier?");
  match s with
    "metavariable" when in_meta -> check_arity_context_linetype s; TMetavariable
  | "identifier" when in_meta || in_rule_name ->
      check_arity_context_linetype s; TIdentifier
  | "type" when in_meta || in_rule_name ->
      check_arity_context_linetype s; TType
  | "parameter" when in_meta ->  check_arity_context_linetype s; TParameter
  | "operator" when in_meta ->   check_arity_context_linetype s; TOperator
  | "binary" when in_meta ->   check_arity_context_linetype s; TBinary
  | "assignment" when in_meta ->   check_arity_context_linetype s; TAssignment
  | "constant"  when in_meta ->  check_arity_context_linetype s; TConstant
  | "generated" when in_rule_name && not (!Flag.make_hrule = None) ->
      check_arity_context_linetype s; TGenerated
  | "expression" when in_meta || in_rule_name ->
      check_arity_context_linetype s; TExpression
  | "declaration" when in_meta || in_rule_name ->
      check_arity_context_linetype s; TDeclaration
  | "field" when in_meta || in_rule_name ->
      check_arity_context_linetype s; TField
  | "initialiser" when in_meta || in_rule_name ->
      check_arity_context_linetype s; TInitialiser
  | "initializer" when in_meta || in_rule_name ->
      check_arity_context_linetype s; TInitialiser
  | "idexpression" when in_meta ->
      check_arity_context_linetype s; TIdExpression
  | "statement" when in_meta ->  check_arity_context_linetype s; TStatement
  | "function"  when in_meta ->  check_arity_context_linetype s; TFunction
  | "local" when in_meta ->      check_arity_context_linetype s; TLocal
  | "global" when in_meta ->     check_arity_context_linetype s; TGlobal
  | "list" when in_meta ->       check_arity_context_linetype s; Tlist
  | "fresh" when in_meta ->      check_arity_context_linetype s; TFresh
  | "typedef" when in_meta ->    check_arity_context_linetype s; TTypedef
  | "attribute" when in_meta ->  check_arity_context_linetype s; TAttribute
  | "declarer" when in_meta ->   check_arity_context_linetype s; TDeclarer
  | "iterator" when in_meta ->   check_arity_context_linetype s; TIterator
  | "name" when in_meta ->       check_arity_context_linetype s; TName
  | "position" when in_meta ->   check_arity_context_linetype s; TPosition
  | "comments" when in_meta ->   check_arity_context_linetype s; TComments
  | "format" when in_meta ->     check_arity_context_linetype s; TFormat
  | "analysis" when in_meta ->   check_arity_context_linetype s; TAnalysis
  | "any" when in_meta ->        check_arity_context_linetype s; TPosAny
  | "pure" when in_meta && in_iso ->
      check_arity_context_linetype s; TPure
  | "context" when in_meta && in_iso ->
      check_arity_context_linetype s; TContext
  | "error" when in_meta ->      check_arity_context_linetype s; TError
  | "words" when in_meta ->      check_context_linetype s; TWords
  | "symbol" when in_meta ->     check_arity_context_linetype s; TSymbol

  | "using" when in_rule_name || in_prolog ->  check_context_linetype s; TUsing
  | "virtual" when in_prolog || in_rule_name || in_meta ->
      (* don't want to allow virtual as a rule name *)
      check_context_linetype s; TVirtual
  | "merge" when in_prolog || in_rule_name || in_meta ->
      check_context_linetype s; TMerge
  | "disable" when in_rule_name ->  check_context_linetype s; TDisable
  | "extends" when in_rule_name -> check_context_linetype s; TExtends
  | "depends" when in_rule_name -> check_context_linetype s; TDepends
  | "on" when in_rule_name      -> check_context_linetype s; TOn
  | "ever" when in_rule_name    -> check_context_linetype s; TEver
  | "never" when in_rule_name   -> check_context_linetype s; TNever
  | "file" when in_rule_name    -> check_context_linetype s; TFile
  | "in" when in_rule_name      -> check_context_linetype s; TIn
  (* exists and forall for when are reparsed in parse_cocci.ml *)
  | "exists" when in_rule_name  -> check_context_linetype s; TExists
  | "forall" when in_rule_name  -> check_context_linetype s; TForall
  | "script" when (in_rule_name || in_meta) ->
      check_context_linetype s; TScript (!file, !line)
  | "initialize" when in_rule_name -> check_context_linetype s; TInitialize
  | "finalize" when in_rule_name   -> check_context_linetype s; TFinalize

  | "char" ->       Tchar     linetype
  | "short" ->      Tshort    linetype
  | "int" ->        Tint      linetype
  | "double" ->     Tdouble   linetype
  | "float" ->      Tfloat    linetype
  | "complex" ->    Tcomplex  linetype
  | "long" ->       Tlong     linetype
  | "void" ->       Tvoid     linetype
  | "size_t" ->     Tsize_t   linetype
  | "ssize_t" ->    Tssize_t  linetype
  | "ptrdiff_t" ->  Tptrdiff_t linetype
  (* in_meta is only for the first keyword; drop it now to allow any type
     name *)
  | "struct" ->     Data.saw_struct := true; Tstruct   linetype
  | "union" ->      Data.saw_struct := true; Tunion    linetype
  | "enum" ->       Data.saw_struct := true; Tenum     linetype
  | "unsigned" ->   Tunsigned linetype
  | "signed" ->     Tsigned   linetype
  | "decimal" when !Flag.ibm -> Tdecimal linetype
  | "EXEC" when !Flag.ibm -> Texec linetype

  | "auto"  ->
      let open Flag in
      begin match !c_plus_plus with
        On None ->
          raise (
            Semantic_cocci.Semantic (
              "auto has different meaning in different versions of
              C++. Please specify a version using --c++=<version>"))
      | On (Some i) ->
          if i >= 2011
          then TautoType linetype
          else Tauto linetype
      | Off -> Tauto linetype end
  | "register" ->   Tregister linetype
  | "extern" ->     Textern   linetype
  | "static" ->     Tstatic   linetype
  | "inline" ->     Tinline   linetype
  | "typedef" ->    Ttypedef  linetype

  | "const" ->      Tconst    linetype
  | "volatile" ->   Tvolatile linetype

  | "if" ->         TIf       linetype
  | "else" ->       TElse     linetype
  | "while" ->      TWhile    linetype
  | "do" ->         TDo       linetype
  | "for" ->        TFor      linetype
  | "switch" ->     TSwitch   linetype
  | "case" ->       TCase     linetype
  | "default" ->    TDefault  linetype
  | "return" ->     TReturn   linetype
  | "break" ->      TBreak    linetype
  | "continue" ->   TContinue linetype
  | "goto" ->       TGoto     linetype

  | "sizeof" ->     TSizeof   linetype
  | "typeof" ->     TTypeof   linetype

  | "Expression"       when !Data.in_iso -> TIsoExpression
  | "ArgExpression"    when !Data.in_iso -> TIsoArgExpression
  | "TestExpression"   when !Data.in_iso -> TIsoTestExpression
  | "ToTestExpression" when !Data.in_iso -> TIsoToTestExpression
  | "Statement"        when !Data.in_iso -> TIsoStatement
  | "Declaration"      when !Data.in_iso -> TIsoDeclaration
  | "Type"             when !Data.in_iso -> TIsoType
  | "TopLevel"         when !Data.in_iso -> TIsoTopLevel

  | "_" when !Data.in_meta -> TUnderscore

  | s -> check_var s linetype

let mkassign op lexbuf =
  TOpAssign (op, (get_current_line_type lexbuf))

let spinit _ = (* per semantic patch *)
  Hashtbl.clear Data.non_local_script_constraints;
  D.type_names := [];
  D.attr_names := [];
  D.iterator_names := [];
  D.declarer_names := []

let init _ = (* per file, first .cocci then iso *)
  line := 1;
  logical_line := 0;
  prev_plus := false;
  line_start := 0;
  current_line_started := false;
  current_line_type := (D.CONTEXT,0,0);
  col_zero := true;
  pm := UNKNOWN;
  Data.in_rule_name := false;
  Data.in_meta := false;
  Data.in_prolog := false;
  Data.saw_struct := false;
  Data.inheritable_positions := [];
  Hashtbl.clear all_metavariables;
  Hashtbl.clear Data.all_metadecls;
  Hashtbl.clear metavariables;
  Hashtbl.clear type_names;
  Hashtbl.clear attr_names;
  Hashtbl.clear rule_names;
  Hashtbl.clear iterator_names;
  Hashtbl.clear declarer_names;
  Hashtbl.clear symbol_names;
  let get_name (_,x) = x in
  Data.add_meta_meta :=
    (fun name cstr pure ->
      let fn clt = TMeta(name,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_id_meta :=
    (fun name constraints pure ->
      let fn clt = TMetaId(name,constraints,Ast.NoVal,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_virt_id_meta_found :=
    (fun name vl ->
      let fn clt = TIdent(vl,clt) in
      Hashtbl.replace metavariables name fn);
  Data.add_virt_id_meta_not_found :=
    (fun name pure ->
      let fn clt = TMetaId(name,Ast.CstrTrue,Ast.NoVal,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_fresh_id_meta :=
    (fun name seed ->
      let fn clt = TMetaId(name,Ast.CstrTrue,seed,Ast0.Impure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_type_meta :=
    (fun name cstr pure ->
      let fn clt = TMetaType(name,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_init_meta :=
    (fun name cstr pure ->
      let fn clt = TMetaInit(name,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_initlist_meta :=
    (fun name lenname cstr pure ->
      let fn clt = TMetaInitList(name,lenname,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_param_meta :=
    (fun name cstr pure ->
      let fn clt = TMetaParam(name,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_paramlist_meta :=
    (fun name lenname cstr pure ->
      let fn clt = TMetaParamList(name,lenname,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_const_meta :=
    (fun tyopt name constraints pure ->
      let fn clt = TMetaConst(name,constraints,pure,tyopt,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_err_meta :=
    (fun name constraints pure ->
      let fn clt = TMetaErr(name,constraints,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_exp_meta :=
    (fun tyopt name constraints pure bitfield ->
      let fn clt = TMetaExp(name,constraints,pure,tyopt,clt,bitfield) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_idexp_meta :=
    (fun tyopt name constraints pure ->
      let fn clt = TMetaIdExp(name,constraints,pure,tyopt,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_local_idexp_meta :=
    (fun tyopt name constraints pure ->
      let fn clt = TMetaLocalIdExp(name,constraints,pure,tyopt,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_global_idexp_meta :=
    (fun tyopt name constraints pure ->
      let fn clt = TMetaGlobalIdExp(name,constraints,pure,tyopt,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_explist_meta :=
    (fun name lenname cstr pure ->
      let fn clt = TMetaExpList(name,lenname,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_decl_meta :=
    (fun name cstr pure ->
      let fn clt = TMetaDecl(name,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_field_meta :=
    (fun name cstr pure ->
      let fn clt = TMetaField(name,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_field_list_meta :=
    (fun name lenname cstr pure ->
      let fn clt = TMetaFieldList(name,lenname,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_fmt_meta :=
    (function name -> function iconstraints ->
      let fn clt = failwith "format metavariable only allowed in a string" in
      Data.format_metavariables :=
	(get_name name,(name,iconstraints)) :: !Data.format_metavariables;
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_fmtlist_meta :=
    (fun name constraints lenname ->
      let fn clt =
	failwith "format list metavariable only allowed in a string" in
      Data.format_list_metavariables :=
	(get_name name,(name,lenname,constraints))
	:: !Data.format_list_metavariables;
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_stm_meta :=
    (fun name cstr pure ->
      let fn clt = TMetaStm(name,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_stmlist_meta :=
    (fun name lenname cstr pure ->
      let fn clt = TMetaStmList(name,lenname,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_dparamlist_meta :=
    (fun name lenname cstr pure ->
      let fn clt = TMetaDParamList(name,lenname,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_func_meta :=
    (fun name constraints pure ->
      let fn clt = TMetaFunc(name,constraints,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_local_func_meta :=
    (fun name constraints pure ->
      let fn clt = TMetaLocalFunc(name,constraints,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_iterator_meta :=
    (fun name constraints pure ->
      let fn clt = TMetaIterator(name,constraints,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_declarer_meta :=
    (fun name constraints pure ->
      let fn clt = TMetaDeclarer(name,constraints,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_pos_meta :=
    (fun name constraints any ->
      let fn ((d,ln,_,_,_,_,_,_,_,_) as clt) =
	(if d = Data.PLUS
	then
	  failwith
	    (Printf.sprintf "%d: positions only allowed in minus code" ln));
	TMetaPos(name,constraints,any,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_com_meta :=
    (fun name constraints ->
      let fn ((d,ln,_,_,_,_,_,_,_,_) as clt) =
	(if d = Data.PLUS
	then
	  failwith
	    (Printf.sprintf "%d: comment variables only allowed in minus code" ln));
	TMetaCom(name,constraints,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_assignOp_meta :=
    (fun name constraints pure ->
      let fn clt = TMetaAssignOp (name, constraints, pure, clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_binaryOp_meta :=
    (fun name constraints pure ->
      let fn clt = TMetaBinaryOp (name, constraints, pure, clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_type_name :=
    (function name ->
      let fn clt = TTypeId(name,clt) in
      (if not (List.mem name !D.type_names)
      then D.type_names := name :: !D.type_names);
      Hashtbl.replace type_names name fn);
  Data.add_attribute :=
    (function name ->
      let fn clt =
	match clt with
	  ((Data.PLUS | Data.PLUSPLUS),_,_,_,_,_,_,_,_,_) ->
	    TDirective (Ast.Space name, clt)
	| _ -> Tattr (name, clt) in
      (if not (List.mem name !D.attr_names)
      then D.attr_names := name :: !D.attr_names);
      Hashtbl.replace attr_names name fn);
  Data.add_attribute_meta :=
    (fun name cstr pure ->
      let fn ((d,ln,_,_,_,_,_,_,_,_) as clt) =
        if (match d with (Data.PLUS | Data.PLUSPLUS) -> true | _ -> false)
        then
          (* TODO support meta attributes in plus code *)
	  failwith
	    (Printf.sprintf
             "%d: meta attributes currently only allowed in context/minus code"
             ln);
        TMetaAttribute(name,cstr,pure,clt) in
      Hashtbl.replace metavariables (get_name name) fn);
  Data.add_declarer_name :=
    (function name ->
      let fn clt = TDeclarerId(name,clt) in
      (if not (List.mem name !D.declarer_names)
      then D.declarer_names := name :: !D.declarer_names);
      Hashtbl.replace declarer_names name fn);
  Data.add_iterator_name :=
    (function name ->
      let fn clt = TIteratorId(name,clt) in
      (if not (List.mem name !D.iterator_names)
      then D.iterator_names := name :: !D.iterator_names);
      Hashtbl.replace iterator_names name fn);
  Data.add_symbol_meta :=
    (function name ->
      let fn clt = TSymId (name,clt) in
      Hashtbl.replace symbol_names name fn);
  Data.init_rule := (function _ -> Hashtbl.clear metavariables);
  Data.install_bindings :=
    (function parent ->
      List.iter (function (name,fn) -> Hashtbl.add metavariables name fn)
	(Hashtbl.find all_metavariables parent))

let post_init _ =
  Stdcompat.Hashtbl.reset all_metavariables;
  Stdcompat.Hashtbl.reset Data.all_metadecls;
  Stdcompat.Hashtbl.reset metavariables;
  Stdcompat.Hashtbl.reset type_names;
  Stdcompat.Hashtbl.reset attr_names;
  Stdcompat.Hashtbl.reset rule_names;
  Stdcompat.Hashtbl.reset iterator_names;
  Stdcompat.Hashtbl.reset declarer_names;
  Stdcompat.Hashtbl.reset symbol_names

(* initialization for each cocci rule *)
let reinit _ =
  Data.format_metavariables := [];
  Data.format_list_metavariables := []

(* the following is needed to properly tokenize include files.  Because an
include file is included after seeing a @, so current_line_started is true.
Current_line_started is not important for parsing the name of a rule, so we
don't have to reset this value to true after parsing an included file. *)
let include_init _ =
  current_line_started := false

let drop_spaces s =
  let len = String.length s in
  let rec loop n =
    if n = len
    then n
    else
      if List.mem (String.get s n) [' ';'\t']
      then loop (n+1)
      else n in
  let start = loop 0 in
  String.sub s start (len - start)

# 609 "parsing_cocci/lexer_cocci.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base =
   "\000\000\152\255\153\255\081\000\119\000\166\255\167\255\192\000\
    \023\001\112\001\201\001\034\002\038\000\067\000\101\000\079\000\
    \217\255\081\000\082\000\085\000\223\255\225\255\228\255\229\255\
    \230\255\231\255\233\255\086\000\192\000\237\255\087\000\239\255\
    \116\000\118\000\140\000\111\002\122\002\209\002\087\000\040\003\
    \069\003\150\000\255\255\155\003\205\000\105\000\150\000\041\000\
    \203\000\154\000\057\000\039\000\057\000\054\000\152\000\238\002\
    \175\000\176\255\210\255\073\000\107\000\089\000\076\000\092\000\
    \084\000\187\255\162\003\096\000\105\000\106\000\222\000\215\003\
    \034\004\107\000\108\000\106\000\117\000\052\001\148\004\231\004\
    \184\255\125\000\120\000\115\000\128\000\054\001\089\005\203\005\
    \240\002\241\000\093\003\127\000\121\000\117\000\153\000\154\000\
    \163\003\237\000\004\001\036\001\166\003\080\001\182\255\006\001\
    \181\255\238\000\180\255\072\001\253\001\075\001\083\002\077\001\
    \085\002\236\002\254\001\171\000\186\000\042\001\186\000\220\000\
    \255\001\086\002\218\000\223\000\173\002\004\001\002\001\204\002\
    \007\001\018\001\205\002\091\001\005\006\092\006\179\006\010\007\
    \097\007\184\007\015\008\102\008\189\008\020\009\107\009\194\009\
    \025\010\112\010\094\001\199\010\030\011\088\011\175\011\233\011\
    \095\001\029\001\064\012\098\001\100\001\151\012\238\012\101\001\
    \069\013\156\013\214\013\045\014\249\255\132\014\219\014\050\015\
    \137\015\224\015\165\003\125\001\137\003\127\001\112\001\244\255\
    \242\255\157\001\224\255\200\003\110\004\120\004\142\001\144\001\
    \145\001\162\001\190\001\192\001\245\255\193\001\196\001\243\255\
    \204\255\203\255\155\255\213\255\198\001\227\255\206\002\212\255\
    \201\001\208\002\199\255\004\000\177\255\189\255\232\255\234\255\
    \236\255\193\255\207\255\211\255\198\255\184\001\185\001\205\255\
    \202\255\209\255\154\255\200\255\194\255\208\255\206\255\026\016\
    \113\016\189\001\171\016\002\017\190\001\089\017\176\017\234\017\
    \065\018\164\255\165\255\162\255\163\255\160\255\161\255\154\018\
    \159\255\156\255\125\003\217\001\229\018\138\004\056\005\079\005\
    \000\019\148\004\089\005\070\019\219\001\157\255\013\002\164\019\
    \189\255\244\019\026\020\200\255\201\255\100\020\187\020\020\021\
    \109\021\198\021\003\002\239\001\013\002\212\002\150\003\017\002\
    \015\002\020\002\064\002\066\002\239\255\240\255\165\005\190\002\
    \243\255\244\255\245\255\246\255\247\255\248\255\207\002\070\003\
    \064\002\183\003\255\255\214\005\122\002\246\002\209\255\216\255\
    \252\255\236\255\251\255\235\255\250\255\219\255\242\255\169\006\
    \188\005\255\006\086\007\234\255\120\002\211\255\217\255\218\255\
    \215\255\225\255\123\002\210\255\214\255\222\255\213\255\221\255\
    \212\255\000\022\087\022\155\002\145\022\232\022\213\002\063\023\
    \150\023\208\023\039\024\208\255\198\255\199\255\242\002\126\024\
    \213\024\243\002\044\025\131\025\189\025\020\026\078\026\244\002\
    \177\002\165\026\247\002\021\003\252\026\083\027\023\003\170\027\
    \001\028\059\028\146\028\196\255\197\255\194\255\195\255\235\028\
    \193\255\190\255\152\003\131\003\054\029\174\007\194\010\143\012\
    \081\029\004\008\091\008\151\029\151\003\191\255\097\003\255\255\
    \061\019\252\255\221\029\084\006\178\008\254\255\244\029\253\255\
    \116\012\254\255\140\019\255\255\251\255\026\030\009\009\096\009\
    \253\255\049\030\252\255\049\019\253\255\135\024\254\255\255\255\
    \250\255\087\030\183\009\014\010\252\255\110\030\251\255\235\007\
    \252\255\253\255\254\255\037\003\255\255";
  Lexing.lex_backtrk =
   "\255\255\255\255\255\255\098\000\098\000\255\255\255\255\083\000\
    \082\000\082\000\082\000\082\000\054\000\067\000\065\000\041\000\
    \255\255\037\000\060\000\033\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\020\000\103\000\255\255\017\000\255\255\
    \015\000\014\000\059\000\029\000\082\000\082\000\007\000\082\000\
    \103\000\034\000\255\255\001\000\255\255\255\255\002\000\255\255\
    \255\255\003\000\255\255\255\255\255\255\255\255\004\000\004\000\
    \004\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \069\000\255\255\255\255\255\255\255\255\255\255\255\255\070\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \072\000\072\000\077\000\255\255\255\255\255\255\255\255\255\255\
    \076\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\077\000\077\000\077\000\077\000\077\000\
    \077\000\077\000\077\000\255\255\255\255\255\255\255\255\255\255\
    \077\000\077\000\255\255\255\255\077\000\255\255\255\255\077\000\
    \255\255\255\255\077\000\255\255\255\255\082\000\082\000\082\000\
    \082\000\082\000\082\000\082\000\082\000\082\000\082\000\082\000\
    \005\000\255\255\085\000\255\255\086\000\255\255\084\000\255\255\
    \255\255\255\255\255\255\084\000\255\255\255\255\255\255\086\000\
    \255\255\086\000\255\255\255\255\255\255\082\000\082\000\008\000\
    \082\000\082\000\097\000\255\255\009\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\097\000\255\255\058\000\064\000\
    \035\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\040\000\255\255\080\000\255\255\
    \039\000\081\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\063\000\036\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \087\000\255\255\255\255\255\255\087\000\255\255\087\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\082\000\
    \255\255\255\255\098\000\098\000\255\255\097\000\255\255\255\255\
    \098\000\097\000\255\255\098\000\098\000\255\255\098\000\255\255\
    \255\255\064\000\064\000\255\255\255\255\049\000\048\000\048\000\
    \048\000\048\000\066\000\035\000\029\000\028\000\027\000\032\000\
    \025\000\022\000\018\000\031\000\255\255\255\255\014\000\023\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\066\000\006\000\
    \066\000\024\000\255\255\001\000\255\255\002\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\063\000\
    \255\255\063\000\255\255\255\255\017\000\255\255\255\255\255\255\
    \255\255\255\255\026\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\053\000\255\255\255\255\255\255\053\000\255\255\
    \053\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\051\000\255\255\052\000\255\255\050\000\255\255\255\255\
    \255\255\255\255\050\000\255\255\255\255\255\255\052\000\255\255\
    \052\000\255\255\255\255\255\255\255\255\255\255\255\255\048\000\
    \255\255\255\255\064\000\064\000\255\255\063\000\255\255\255\255\
    \064\000\063\000\255\255\064\000\064\000\255\255\255\255\255\255\
    \000\000\255\255\003\000\001\000\001\000\255\255\002\000\255\255\
    \255\255\255\255\001\000\255\255\255\255\004\000\002\000\002\000\
    \255\255\003\000\255\255\255\255\255\255\002\000\255\255\255\255\
    \255\255\005\000\003\000\003\000\255\255\004\000\255\255\255\255\
    \255\255\255\255\255\255\004\000\255\255";
  Lexing.lex_default =
   "\001\000\000\000\000\000\255\255\255\255\000\000\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\255\255\000\000\255\255\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\046\000\255\255\
    \255\255\049\000\255\255\255\255\255\255\255\255\255\255\056\000\
    \056\000\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \089\000\089\000\107\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\103\000\101\000\255\255\101\000\000\000\103\000\
    \000\000\255\255\000\000\107\000\107\000\107\000\107\000\111\000\
    \107\000\107\000\114\000\255\255\255\255\255\255\255\255\255\255\
    \120\000\121\000\255\255\255\255\124\000\255\255\255\255\127\000\
    \255\255\255\255\130\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \000\000\255\255\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\255\255\255\255\000\000\
    \000\000\000\000\000\000\000\000\255\255\000\000\198\000\000\000\
    \255\255\201\000\000\000\255\255\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\255\255\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\255\255\
    \000\000\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\000\001\
    \000\000\255\255\255\255\000\000\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\000\000\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\037\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\255\255\
    \255\255\255\255\255\255\000\000\255\255\000\000\000\000\000\000\
    \000\000\000\000\255\255\000\000\000\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\000\000\000\000\000\000\255\255\
    \000\000\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\119\001\000\000\
    \121\001\000\000\255\255\255\255\255\255\000\000\255\255\000\000\
    \129\001\000\000\132\001\000\000\000\000\255\255\255\255\255\255\
    \000\000\255\255\000\000\140\001\000\000\144\001\000\000\000\000\
    \000\000\255\255\255\255\255\255\000\000\255\255\000\000\152\001\
    \000\000\000\000\000\000\255\255\000\000";
  Lexing.lex_trans =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\043\000\042\000\042\000\042\000\042\000\204\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \043\000\030\000\005\000\040\000\007\000\017\000\014\000\006\000\
    \029\000\026\000\019\000\032\000\021\000\033\000\035\000\041\000\
    \004\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\012\000\020\000\034\000\015\000\018\000\031\000\
    \038\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\011\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\010\000\008\000\037\000\
    \008\000\008\000\008\000\025\000\028\000\024\000\013\000\039\000\
    \223\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\009\000\008\000\036\000\
    \008\000\008\000\008\000\023\000\027\000\022\000\016\000\245\000\
    \222\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\220\000\219\000\218\000\217\000\212\000\
    \213\000\214\000\211\000\210\000\202\000\241\000\246\000\164\000\
    \046\000\050\000\051\000\052\000\053\000\242\000\054\000\200\000\
    \255\255\055\000\221\000\196\000\255\255\245\000\243\000\248\000\
    \248\000\248\000\248\000\248\000\248\000\248\000\248\000\247\000\
    \247\000\199\000\128\000\195\000\197\000\241\000\246\000\185\000\
    \055\000\255\255\186\000\241\000\246\000\242\000\081\000\090\000\
    \057\000\073\000\067\000\242\000\068\000\046\000\243\000\091\000\
    \183\000\182\000\204\000\184\000\243\000\203\000\069\000\244\000\
    \070\000\074\000\209\000\058\000\048\000\075\000\048\000\117\000\
    \076\000\116\000\077\000\241\000\246\000\115\000\082\000\083\000\
    \084\000\085\000\092\000\242\000\007\000\093\000\205\000\071\000\
    \208\000\206\000\094\000\048\000\243\000\048\000\049\000\244\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\131\000\255\255\132\000\095\000\071\000\096\000\
    \002\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\105\000\106\000\125\000\122\000\007\000\
    \121\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\207\000\078\000\047\000\086\000\
    \047\000\120\000\255\255\123\000\104\000\124\000\255\255\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\131\000\255\255\132\000\078\000\255\255\086\000\255\255\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\102\000\126\000\127\000\129\000\008\000\130\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\237\000\118\000\007\000\147\000\255\255\238\000\
    \131\000\153\000\255\255\149\000\152\000\119\000\160\000\156\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \239\000\008\000\131\000\172\000\132\000\177\000\176\000\255\255\
    \110\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\178\000\194\000\193\000\192\000\008\000\
    \189\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\235\000\187\000\007\000\188\000\190\000\
    \236\000\255\255\191\000\198\000\201\000\216\000\215\000\229\000\
    \225\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\131\000\255\255\132\000\255\255\255\255\
    \255\255\255\255\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\255\255\252\000\075\001\253\000\
    \008\000\065\001\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\233\000\252\000\007\000\253\000\
    \255\255\234\000\064\001\255\255\056\001\255\255\057\001\058\001\
    \255\255\055\001\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\131\000\255\255\132\000\255\255\
    \255\255\112\000\253\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\054\001\052\001\051\001\
    \040\001\008\000\253\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\171\000\007\000\170\000\
    \170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\
    \170\000\037\001\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\131\000\053\001\132\000\255\255\
    \059\001\111\000\113\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\071\001\255\255\255\255\
    \255\255\008\000\255\255\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\168\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\007\000\255\255\055\000\
    \255\255\088\000\255\255\045\001\046\001\255\255\255\255\255\255\
    \255\255\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\131\000\043\001\132\000\055\000\067\001\
    \088\000\062\001\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\165\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\082\001\078\001\088\001\084\001\
    \008\000\087\001\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\007\000\044\001\066\000\095\001\
    \063\001\091\001\114\000\255\255\156\001\255\255\255\255\000\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\131\000\000\000\132\000\066\000\049\000\255\255\
    \065\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\041\001\000\000\000\000\000\000\133\000\
    \000\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\000\000\043\000\042\000\042\000\042\000\
    \042\000\063\000\060\000\066\000\100\000\255\255\061\000\100\000\
    \000\000\059\000\000\000\000\000\174\000\062\000\000\000\173\000\
    \047\000\000\000\064\000\043\000\061\001\120\001\044\000\000\000\
    \000\000\109\000\066\000\100\000\042\001\099\000\100\000\175\000\
    \099\000\254\000\045\000\108\000\255\255\255\255\255\255\116\001\
    \255\255\097\000\253\000\060\001\097\000\170\000\170\000\170\000\
    \170\000\170\000\170\000\170\000\170\000\170\000\170\000\098\000\
    \071\000\038\001\098\000\117\001\117\001\000\000\037\001\000\000\
    \000\000\254\000\179\000\000\000\255\255\117\001\255\255\116\001\
    \255\255\000\000\253\000\181\000\039\001\181\000\255\255\071\000\
    \180\000\180\000\180\000\180\000\180\000\180\000\180\000\180\000\
    \180\000\180\000\000\000\117\001\117\001\000\000\063\000\060\000\
    \000\000\000\000\179\000\061\000\000\000\117\001\059\000\000\000\
    \000\000\000\000\062\000\000\000\000\000\047\000\000\000\064\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\000\000\000\000\000\000\000\000\072\000\000\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\000\000\255\255\000\000\000\000\
    \000\000\255\255\000\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\000\000\000\000\000\000\
    \000\000\072\000\000\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\078\000\180\000\180\000\
    \180\000\180\000\180\000\180\000\180\000\180\000\180\000\180\000\
    \180\000\180\000\180\000\180\000\180\000\180\000\180\000\180\000\
    \180\000\180\000\000\000\000\000\078\000\000\000\000\000\000\000\
    \000\000\000\000\245\000\245\000\245\000\245\000\245\000\245\000\
    \245\000\245\000\245\000\245\000\249\000\249\000\249\000\249\000\
    \249\000\249\000\249\000\249\000\249\000\249\000\000\000\179\000\
    \000\000\000\000\000\000\000\000\000\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\179\000\
    \000\000\000\000\000\000\079\000\000\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\080\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\000\000\000\000\000\000\000\000\079\000\000\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\086\000\250\000\000\000\250\000\000\000\000\000\
    \249\000\249\000\249\000\249\000\249\000\249\000\249\000\249\000\
    \249\000\249\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\086\000\000\000\000\000\000\000\245\000\000\000\247\000\
    \247\000\247\000\247\000\247\000\247\000\247\000\247\000\247\000\
    \247\000\249\000\249\000\249\000\249\000\249\000\249\000\249\000\
    \249\000\249\000\249\000\000\000\246\000\000\000\000\000\000\000\
    \000\000\000\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\246\000\000\000\000\000\000\000\
    \087\000\000\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\088\000\047\001\047\001\047\001\
    \047\001\047\001\047\001\047\001\047\001\047\001\047\001\035\001\
    \034\001\034\001\034\001\034\001\000\000\000\000\000\000\050\001\
    \000\000\050\001\000\000\088\000\049\001\049\001\049\001\049\001\
    \049\001\049\001\049\001\049\001\049\001\049\001\035\001\000\000\
    \000\000\000\000\000\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\036\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\000\000\000\000\
    \000\000\145\000\087\000\000\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \000\000\000\000\000\000\000\000\145\000\000\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \007\000\000\000\000\000\145\000\124\001\124\001\124\001\124\001\
    \124\001\124\001\124\001\124\001\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\131\000\000\000\
    \132\000\000\000\000\000\000\000\000\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\000\000\
    \000\000\000\000\000\000\008\000\000\000\134\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\007\000\
    \000\000\047\001\047\001\047\001\047\001\047\001\047\001\047\001\
    \047\001\047\001\047\001\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\131\000\048\001\132\000\
    \000\000\000\000\000\000\000\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\048\001\000\000\
    \000\000\000\000\008\000\000\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\135\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\007\000\049\001\
    \049\001\049\001\049\001\049\001\049\001\049\001\049\001\049\001\
    \049\001\000\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\131\000\000\000\132\000\000\000\
    \000\000\000\000\000\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\000\000\000\000\000\000\
    \000\000\008\000\000\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\136\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\007\000\049\001\049\001\
    \049\001\049\001\049\001\049\001\049\001\049\001\049\001\049\001\
    \000\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\131\000\000\000\132\000\000\000\000\000\
    \000\000\000\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\000\000\000\000\000\000\000\000\
    \008\000\000\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\137\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\007\000\000\000\109\001\109\001\
    \109\001\109\001\109\001\109\001\109\001\109\001\109\001\109\001\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\131\000\048\001\132\000\154\001\154\001\154\001\
    \154\001\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\048\001\000\000\155\001\153\001\008\000\
    \000\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\138\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\007\000\113\001\113\001\113\001\113\001\
    \113\001\113\001\113\001\113\001\113\001\113\001\000\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\131\000\000\000\132\000\000\000\000\000\000\000\000\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\000\000\000\000\000\000\000\000\008\000\000\000\
    \008\000\139\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\007\000\113\001\113\001\113\001\113\001\113\001\
    \113\001\113\001\113\001\113\001\113\001\000\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \131\000\000\000\132\000\000\000\000\000\000\000\000\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\000\000\000\000\000\000\000\000\008\000\000\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\140\000\008\000\008\000\008\000\008\000\
    \008\000\007\000\125\001\125\001\125\001\125\001\125\001\125\001\
    \125\001\125\001\000\000\255\255\000\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\131\000\
    \000\000\132\000\000\000\000\000\000\000\000\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \000\000\000\000\000\000\000\000\008\000\000\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\141\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \007\000\135\001\135\001\135\001\135\001\135\001\135\001\135\001\
    \135\001\000\000\000\000\000\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\131\000\000\000\
    \132\000\000\000\000\000\000\000\000\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\000\000\
    \000\000\000\000\000\000\008\000\000\000\008\000\008\000\008\000\
    \008\000\142\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\007\000\
    \136\001\136\001\136\001\136\001\136\001\136\001\136\001\136\001\
    \000\000\000\000\000\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\131\000\000\000\132\000\
    \000\000\000\000\000\000\000\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\000\000\000\000\
    \000\000\000\000\143\000\000\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\007\000\147\001\
    \147\001\147\001\147\001\147\001\147\001\147\001\147\001\000\000\
    \000\000\000\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\131\000\000\000\132\000\000\000\
    \000\000\000\000\000\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\000\000\000\000\000\000\
    \000\000\144\000\000\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\007\000\148\001\148\001\
    \148\001\148\001\148\001\148\001\148\001\148\001\000\000\000\000\
    \000\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\131\000\000\000\132\000\000\000\000\000\
    \000\000\000\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\000\000\000\000\000\000\000\000\
    \008\000\000\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\145\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\000\000\000\000\000\000\000\000\146\000\000\000\
    \000\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\000\000\000\000\000\000\000\000\145\000\
    \000\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\148\000\000\000\114\001\145\000\114\001\
    \000\000\000\000\113\001\113\001\113\001\113\001\113\001\113\001\
    \113\001\113\001\113\001\113\001\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\000\000\000\000\000\000\000\000\148\000\000\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\148\000\000\000\000\000\149\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \156\000\000\000\157\000\000\000\000\000\000\000\000\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\000\000\000\000\000\000\150\000\148\000\000\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\000\000\000\000\000\000\000\000\150\000\
    \000\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\150\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\152\000\000\000\151\000\000\000\000\000\000\000\000\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\000\000\000\000\000\000\154\000\150\000\000\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\000\000\000\000\000\000\000\000\
    \154\000\000\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\154\000\000\000\000\000\154\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\000\000\000\000\000\000\000\000\155\000\000\000\
    \000\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\131\001\000\000\000\000\000\000\154\000\
    \000\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\158\000\000\000\109\001\154\000\111\001\
    \111\001\111\001\111\001\111\001\111\001\111\001\111\001\111\001\
    \111\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \130\001\000\000\000\000\000\000\110\001\000\000\000\000\000\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\000\000\000\000\110\001\000\000\158\000\000\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\158\000\000\000\000\000\158\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \000\000\000\000\000\000\000\000\159\000\000\000\000\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\000\000\000\000\000\000\000\000\158\000\000\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\161\000\000\000\000\000\158\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\255\255\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \000\000\000\000\000\000\000\000\161\000\000\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\156\000\000\000\
    \162\000\000\000\000\000\000\000\000\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\000\000\
    \000\000\000\000\163\000\161\000\000\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\000\000\000\000\000\000\000\000\163\000\000\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\000\000\000\000\163\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\000\000\
    \000\000\000\000\000\000\159\000\000\000\000\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \000\000\000\000\000\000\000\000\163\000\000\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \007\000\000\000\000\000\163\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\131\000\000\000\
    \132\000\000\000\000\000\000\000\000\000\008\000\008\000\008\000\
    \008\000\166\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\000\000\
    \000\000\000\000\000\000\008\000\000\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\007\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\131\000\000\000\132\000\
    \000\000\000\000\000\000\000\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\167\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\000\000\000\000\
    \000\000\000\000\008\000\000\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\007\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\131\000\000\000\132\000\000\000\
    \000\000\000\000\000\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\000\000\000\000\000\000\
    \000\000\008\000\000\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\007\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\131\000\000\000\132\000\000\000\000\000\
    \000\000\000\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\000\000\000\000\000\000\000\000\
    \008\000\000\000\008\000\008\000\008\000\008\000\169\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\007\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\131\000\000\000\132\000\000\000\000\000\000\000\
    \000\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\000\000\000\000\000\000\224\000\008\000\
    \000\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\167\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\000\000\000\000\000\000\
    \000\000\224\000\000\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\225\000\000\000\226\000\000\000\000\000\
    \000\000\000\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\000\000\000\000\000\000\227\000\
    \224\000\000\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\000\000\000\000\
    \000\000\000\000\227\000\000\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\227\000\000\000\
    \000\000\227\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\000\000\000\000\000\000\000\000\
    \228\000\000\000\000\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\000\000\000\000\000\000\
    \000\000\227\000\000\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\230\000\000\000\000\000\
    \227\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\000\000\000\000\000\000\000\000\
    \230\000\000\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\225\000\000\000\231\000\000\000\000\000\000\000\
    \000\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\000\000\000\000\000\000\232\000\230\000\
    \000\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\000\000\000\000\000\000\
    \000\000\232\000\000\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\232\000\000\000\000\000\
    \232\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\000\000\000\000\000\000\000\000\228\000\
    \000\000\000\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\000\000\000\000\000\000\000\000\
    \232\000\000\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\240\000\000\000\007\000\232\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\131\000\000\000\132\000\000\000\
    \000\000\000\000\000\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\000\000\000\000\000\000\
    \000\000\008\000\000\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\251\000\251\000\251\000\
    \251\000\251\000\251\000\251\000\251\000\251\000\251\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\251\000\251\000\
    \251\000\251\000\251\000\251\000\000\000\000\000\245\000\000\000\
    \248\000\248\000\248\000\248\000\248\000\248\000\248\000\248\000\
    \247\000\247\000\000\000\142\001\142\001\142\001\142\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\246\000\251\000\251\000\
    \251\000\251\000\251\000\251\000\242\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\143\001\000\000\243\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\246\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\242\000\123\001\123\001\123\001\
    \123\001\123\001\123\001\123\001\123\001\243\000\251\000\251\000\
    \251\000\251\000\251\000\251\000\251\000\251\000\251\000\251\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\251\000\
    \251\000\251\000\251\000\251\000\251\000\141\001\000\000\000\000\
    \000\000\000\000\242\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\243\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\251\000\
    \251\000\251\000\251\000\251\000\251\000\035\001\034\001\034\001\
    \034\001\034\001\242\000\000\000\000\000\122\001\000\000\000\000\
    \000\000\000\000\000\000\243\000\134\001\134\001\134\001\134\001\
    \134\001\134\001\134\001\134\001\035\001\030\001\003\001\010\001\
    \005\001\016\001\014\001\004\001\029\001\028\001\018\001\017\001\
    \021\001\023\001\022\001\033\001\002\001\001\001\001\001\001\001\
    \001\001\001\001\001\001\001\001\001\001\001\001\011\001\020\001\
    \019\001\031\001\015\001\000\000\032\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \009\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\008\001\006\001\006\001\006\001\006\001\006\001\027\001\
    \000\000\026\001\012\001\006\001\133\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\007\001\006\001\006\001\006\001\006\001\006\001\025\001\
    \013\001\024\001\109\001\000\000\001\001\001\001\001\001\001\001\
    \001\001\001\001\001\001\001\001\001\001\001\001\000\000\000\000\
    \000\000\255\255\000\000\000\000\000\000\000\000\000\000\000\000\
    \105\001\110\001\000\000\000\000\000\000\255\255\000\000\000\000\
    \106\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \109\001\107\001\112\001\112\001\112\001\112\001\112\001\112\001\
    \112\001\112\001\111\001\111\001\000\000\000\000\000\000\000\000\
    \105\001\110\001\000\000\000\000\000\000\000\000\105\001\110\001\
    \106\001\000\000\000\000\000\000\000\000\000\000\106\001\000\000\
    \000\000\107\001\000\000\000\000\000\000\000\000\000\000\107\001\
    \000\000\000\000\108\001\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\105\001\110\001\
    \000\000\000\000\000\000\000\000\000\000\000\000\106\001\000\000\
    \005\001\000\000\000\000\000\000\255\255\000\000\000\000\107\001\
    \000\000\000\000\108\001\000\000\005\001\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\078\001\000\000\
    \079\001\000\000\000\000\000\000\255\255\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\005\001\000\000\
    \000\000\000\000\000\000\005\001\000\000\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\005\001\005\001\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\078\001\000\000\079\001\
    \000\000\000\000\000\000\000\000\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\000\000\000\000\
    \000\000\000\000\006\001\000\000\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\101\001\000\000\
    \005\001\000\000\000\000\102\001\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\103\001\006\001\078\001\000\000\
    \079\001\000\000\000\000\000\000\000\000\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\000\000\
    \000\000\000\000\000\000\006\001\000\000\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\099\001\
    \000\000\005\001\000\000\000\000\100\001\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\078\001\
    \000\000\079\001\000\000\000\000\000\000\000\000\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \000\000\000\000\000\000\000\000\006\001\000\000\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \076\001\000\000\005\001\000\000\000\000\077\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \078\001\000\000\079\001\000\000\000\000\000\000\000\000\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\000\000\000\000\000\000\066\001\006\001\000\000\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\000\000\000\000\000\000\000\000\066\001\
    \000\000\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\067\001\000\000\068\001\000\000\000\000\000\000\000\000\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\000\000\000\000\000\000\069\001\066\001\000\000\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\000\000\000\000\000\000\000\000\
    \069\001\000\000\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\069\001\000\000\000\000\069\001\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\000\000\000\000\000\000\000\000\070\001\000\000\
    \000\000\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\000\000\000\000\000\000\000\000\069\001\
    \000\000\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\072\001\000\000\000\000\069\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\000\000\000\000\000\000\000\000\072\001\000\000\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\072\001\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \067\001\000\000\073\001\000\000\000\000\000\000\000\000\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\000\000\000\000\000\000\074\001\072\001\000\000\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\000\000\000\000\000\000\000\000\074\001\
    \000\000\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\074\001\000\000\000\000\074\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\000\000\000\000\000\000\000\000\070\001\000\000\000\000\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\000\000\000\000\000\000\000\000\074\001\000\000\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\080\001\000\000\000\000\074\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\146\001\
    \146\001\146\001\146\001\146\001\146\001\146\001\146\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\000\000\000\000\000\000\000\000\080\001\000\000\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\080\001\000\000\000\000\080\001\000\000\000\000\145\001\
    \000\000\000\000\000\000\000\000\000\000\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\000\000\
    \000\000\000\000\000\000\081\001\000\000\000\000\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \000\000\000\000\000\000\000\000\080\001\000\000\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \083\001\000\000\000\000\080\001\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\255\255\
    \000\000\000\000\000\000\083\001\000\000\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
    \000\000\000\000\084\001\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\091\001\000\000\092\001\
    \000\000\000\000\000\000\000\000\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\000\000\000\000\
    \000\000\085\001\083\001\000\000\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \000\000\000\000\000\000\000\000\085\001\000\000\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \085\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\087\001\000\000\
    \086\001\000\000\000\000\000\000\000\000\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\000\000\
    \000\000\000\000\089\001\085\001\000\000\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\000\000\000\000\000\000\000\000\089\001\000\000\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\089\001\000\000\000\000\089\001\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\000\000\
    \000\000\000\000\000\000\090\001\000\000\000\000\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \000\000\000\000\000\000\000\000\089\001\000\000\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \093\001\000\000\000\000\089\001\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\000\000\
    \000\000\000\000\000\000\093\001\000\000\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \000\000\000\000\093\001\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\000\000\000\000\000\000\
    \000\000\094\001\000\000\000\000\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\000\000\000\000\
    \000\000\000\000\093\001\000\000\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\096\001\000\000\
    \000\000\093\001\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\000\000\000\000\000\000\
    \000\000\096\001\000\000\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\091\001\000\000\097\001\000\000\000\000\
    \000\000\000\000\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\000\000\000\000\000\000\098\001\
    \096\001\000\000\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\000\000\000\000\
    \000\000\000\000\098\001\000\000\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\098\001\000\000\
    \000\000\098\001\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\000\000\000\000\000\000\000\000\
    \094\001\000\000\000\000\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\000\000\000\000\000\000\
    \000\000\098\001\000\000\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\104\001\000\000\005\001\
    \098\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\078\001\000\000\079\001\
    \000\000\000\000\000\000\000\000\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\000\000\000\000\
    \000\000\000\000\006\001\000\000\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\115\001\115\001\
    \115\001\115\001\115\001\115\001\115\001\115\001\115\001\115\001\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\115\001\
    \115\001\115\001\115\001\115\001\115\001\000\000\000\000\109\001\
    \000\000\112\001\112\001\112\001\112\001\112\001\112\001\112\001\
    \112\001\111\001\111\001\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\110\001\115\001\
    \115\001\115\001\115\001\115\001\115\001\106\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\107\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\110\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\106\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\107\001\115\001\
    \115\001\115\001\115\001\115\001\115\001\115\001\115\001\115\001\
    \115\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \115\001\115\001\115\001\115\001\115\001\115\001\000\000\000\000\
    \000\000\000\000\000\000\106\001\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\107\001\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \115\001\115\001\115\001\115\001\115\001\115\001\000\000\000\000\
    \000\000\000\000\000\000\106\001\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\107\001\126\001\126\001\126\001\
    \126\001\126\001\126\001\126\001\126\001\126\001\126\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\126\001\126\001\
    \126\001\126\001\126\001\126\001\127\001\127\001\127\001\127\001\
    \127\001\127\001\127\001\127\001\127\001\127\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\127\001\127\001\127\001\
    \127\001\127\001\127\001\000\000\000\000\000\000\126\001\126\001\
    \126\001\126\001\126\001\126\001\000\000\000\000\000\000\000\000\
    \000\000\000\000\137\001\137\001\137\001\137\001\137\001\137\001\
    \137\001\137\001\137\001\137\001\000\000\127\001\127\001\127\001\
    \127\001\127\001\127\001\137\001\137\001\137\001\137\001\137\001\
    \137\001\138\001\138\001\138\001\138\001\138\001\138\001\138\001\
    \138\001\138\001\138\001\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\138\001\138\001\138\001\138\001\138\001\138\001\
    \000\000\000\000\000\000\137\001\137\001\137\001\137\001\137\001\
    \137\001\000\000\000\000\000\000\000\000\000\000\000\000\149\001\
    \149\001\149\001\149\001\149\001\149\001\149\001\149\001\149\001\
    \149\001\000\000\138\001\138\001\138\001\138\001\138\001\138\001\
    \149\001\149\001\149\001\149\001\149\001\149\001\150\001\150\001\
    \150\001\150\001\150\001\150\001\150\001\150\001\150\001\150\001\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\150\001\
    \150\001\150\001\150\001\150\001\150\001\000\000\000\000\000\000\
    \149\001\149\001\149\001\149\001\149\001\149\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\150\001\
    \150\001\150\001\150\001\150\001\150\001\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_check =
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\000\000\000\000\000\000\203\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \012\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\003\000\
    \013\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
    \003\000\003\000\003\000\014\000\015\000\015\000\017\000\018\000\
    \018\000\018\000\019\000\027\000\030\000\003\000\003\000\038\000\
    \045\000\047\000\050\000\051\000\052\000\003\000\053\000\032\000\
    \046\000\054\000\014\000\033\000\049\000\004\000\003\000\004\000\
    \004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
    \004\000\032\000\059\000\033\000\033\000\003\000\003\000\034\000\
    \054\000\056\000\034\000\004\000\004\000\003\000\062\000\061\000\
    \041\000\063\000\064\000\004\000\067\000\041\000\003\000\061\000\
    \034\000\034\000\028\000\034\000\004\000\028\000\068\000\004\000\
    \069\000\073\000\027\000\041\000\048\000\074\000\044\000\060\000\
    \075\000\060\000\076\000\004\000\004\000\060\000\081\000\082\000\
    \083\000\084\000\091\000\004\000\007\000\092\000\028\000\070\000\
    \028\000\028\000\093\000\048\000\004\000\044\000\044\000\004\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\089\000\007\000\094\000\070\000\095\000\
    \000\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\097\000\105\000\115\000\116\000\007\000\
    \118\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\007\000\007\000\007\000\007\000\007\000\
    \007\000\007\000\007\000\008\000\028\000\077\000\048\000\085\000\
    \044\000\119\000\098\000\122\000\103\000\123\000\099\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\107\000\008\000\077\000\109\000\085\000\111\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\101\000\125\000\126\000\128\000\008\000\129\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
    \008\000\008\000\009\000\117\000\009\000\131\000\046\000\009\000\
    \146\000\152\000\049\000\153\000\155\000\117\000\156\000\159\000\
    \009\000\009\000\009\000\009\000\009\000\009\000\009\000\009\000\
    \009\000\009\000\009\000\171\000\009\000\173\000\174\000\056\000\
    \109\000\009\000\009\000\009\000\009\000\009\000\009\000\009\000\
    \009\000\009\000\009\000\009\000\009\000\009\000\009\000\009\000\
    \009\000\009\000\009\000\009\000\009\000\009\000\009\000\009\000\
    \009\000\009\000\009\000\177\000\182\000\183\000\184\000\009\000\
    \185\000\009\000\009\000\009\000\009\000\009\000\009\000\009\000\
    \009\000\009\000\009\000\009\000\009\000\009\000\009\000\009\000\
    \009\000\009\000\009\000\009\000\009\000\009\000\009\000\009\000\
    \009\000\009\000\009\000\010\000\186\000\010\000\187\000\189\000\
    \010\000\089\000\190\000\196\000\200\000\213\000\214\000\225\000\
    \228\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\098\000\010\000\103\000\108\000\
    \114\000\120\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\099\000\243\000\010\001\252\000\
    \010\000\011\001\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\010\000\010\000\010\000\010\000\
    \010\000\010\000\010\000\010\000\011\000\243\000\011\000\252\000\
    \107\000\011\000\012\001\109\000\016\001\111\000\015\001\015\001\
    \101\000\017\001\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\110\000\011\000\112\000\
    \121\000\108\000\254\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\018\001\019\001\019\001\
    \032\001\011\000\254\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\035\000\036\000\035\000\
    \035\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\036\001\036\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\036\000\036\000\036\000\036\000\052\001\036\000\124\000\
    \058\001\110\000\112\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\036\000\036\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\036\000\036\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\036\000\036\000\036\000\036\000\067\001\127\000\130\000\
    \198\000\036\000\201\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\036\000\036\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\036\000\036\000\036\000\036\000\036\000\036\000\036\000\
    \036\000\036\000\036\000\036\000\036\000\037\000\113\000\055\000\
    \055\000\088\000\088\000\023\001\023\001\108\000\114\000\120\000\
    \037\001\037\000\037\000\037\000\037\000\037\000\037\000\037\000\
    \037\000\037\000\037\000\037\000\030\001\037\000\055\000\070\001\
    \088\000\013\001\037\000\037\000\037\000\037\000\037\000\037\000\
    \037\000\037\000\037\000\037\000\037\000\037\000\037\000\037\000\
    \037\000\037\000\037\000\037\000\037\000\037\000\037\000\037\000\
    \037\000\037\000\037\000\037\000\078\001\081\001\087\001\088\001\
    \037\000\090\001\037\000\037\000\037\000\037\000\037\000\037\000\
    \037\000\037\000\037\000\037\000\037\000\037\000\037\000\037\000\
    \037\000\037\000\037\000\037\000\037\000\037\000\037\000\037\000\
    \037\000\037\000\037\000\037\000\039\000\030\001\040\000\091\001\
    \013\001\094\001\113\000\110\000\155\001\112\000\121\000\255\255\
    \039\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\255\255\039\000\040\000\040\000\090\000\
    \040\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\031\001\255\255\255\255\255\255\039\000\
    \255\255\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\255\255\043\000\043\000\043\000\043\000\
    \043\000\040\000\040\000\066\000\096\000\124\000\040\000\100\000\
    \255\255\040\000\255\255\255\255\172\000\040\000\255\255\172\000\
    \040\000\255\255\040\000\043\000\014\001\118\001\043\000\255\255\
    \255\255\090\000\066\000\096\000\031\001\096\000\100\000\172\000\
    \100\000\242\000\043\000\090\000\127\000\130\000\198\000\107\001\
    \201\000\096\000\242\000\014\001\100\000\170\000\170\000\170\000\
    \170\000\170\000\170\000\170\000\170\000\170\000\170\000\096\000\
    \071\000\033\001\100\000\116\001\106\001\255\255\033\001\255\255\
    \255\255\242\000\170\000\255\255\113\000\106\001\055\000\107\001\
    \088\000\255\255\242\000\179\000\033\001\179\000\037\001\071\000\
    \179\000\179\000\179\000\179\000\179\000\179\000\179\000\179\000\
    \179\000\179\000\255\255\116\001\106\001\255\255\066\000\066\000\
    \255\255\255\255\170\000\066\000\255\255\106\001\066\000\255\255\
    \255\255\255\255\066\000\255\255\255\255\066\000\255\255\066\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\255\255\255\255\255\255\255\255\071\000\255\255\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\255\255\090\000\255\255\255\255\
    \255\255\118\001\255\255\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\255\255\255\255\255\255\
    \255\255\072\000\255\255\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\072\000\072\000\072\000\
    \072\000\072\000\072\000\072\000\072\000\078\000\180\000\180\000\
    \180\000\180\000\180\000\180\000\180\000\180\000\180\000\180\000\
    \181\000\181\000\181\000\181\000\181\000\181\000\181\000\181\000\
    \181\000\181\000\255\255\255\255\078\000\255\255\255\255\255\255\
    \255\255\255\255\245\000\245\000\245\000\245\000\245\000\245\000\
    \245\000\245\000\245\000\245\000\249\000\249\000\249\000\249\000\
    \249\000\249\000\249\000\249\000\249\000\249\000\255\255\245\000\
    \255\255\255\255\255\255\255\255\255\255\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\245\000\
    \255\255\255\255\255\255\078\000\255\255\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\079\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\255\255\255\255\255\255\255\255\079\000\255\255\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\079\000\086\000\246\000\255\255\246\000\255\255\255\255\
    \246\000\246\000\246\000\246\000\246\000\246\000\246\000\246\000\
    \246\000\246\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\086\000\255\255\255\255\255\255\247\000\255\255\247\000\
    \247\000\247\000\247\000\247\000\247\000\247\000\247\000\247\000\
    \247\000\250\000\250\000\250\000\250\000\250\000\250\000\250\000\
    \250\000\250\000\250\000\255\255\247\000\255\255\255\255\255\255\
    \255\255\255\255\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\247\000\255\255\255\255\255\255\
    \086\000\255\255\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\087\000\022\001\022\001\022\001\
    \022\001\022\001\022\001\022\001\022\001\022\001\022\001\035\001\
    \035\001\035\001\035\001\035\001\255\255\255\255\255\255\048\001\
    \255\255\048\001\255\255\087\000\048\001\048\001\048\001\048\001\
    \048\001\048\001\048\001\048\001\048\001\048\001\035\001\255\255\
    \255\255\255\255\255\255\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\035\001\255\255\255\255\
    \255\255\255\255\255\255\255\255\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\255\255\255\255\
    \255\255\132\000\087\000\255\255\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\132\000\132\000\
    \132\000\132\000\132\000\132\000\132\000\132\000\132\000\132\000\
    \132\000\132\000\132\000\132\000\132\000\132\000\132\000\132\000\
    \132\000\132\000\132\000\132\000\132\000\132\000\132\000\132\000\
    \255\255\255\255\255\255\255\255\132\000\255\255\132\000\132\000\
    \132\000\132\000\132\000\132\000\132\000\132\000\132\000\132\000\
    \132\000\132\000\132\000\132\000\132\000\132\000\132\000\132\000\
    \132\000\132\000\132\000\132\000\132\000\132\000\132\000\132\000\
    \133\000\255\255\255\255\132\000\123\001\123\001\123\001\123\001\
    \123\001\123\001\123\001\123\001\133\000\133\000\133\000\133\000\
    \133\000\133\000\133\000\133\000\133\000\133\000\133\000\255\255\
    \133\000\255\255\255\255\255\255\255\255\133\000\133\000\133\000\
    \133\000\133\000\133\000\133\000\133\000\133\000\133\000\133\000\
    \133\000\133\000\133\000\133\000\133\000\133\000\133\000\133\000\
    \133\000\133\000\133\000\133\000\133\000\133\000\133\000\255\255\
    \255\255\255\255\255\255\133\000\255\255\133\000\133\000\133\000\
    \133\000\133\000\133\000\133\000\133\000\133\000\133\000\133\000\
    \133\000\133\000\133\000\133\000\133\000\133\000\133\000\133\000\
    \133\000\133\000\133\000\133\000\133\000\133\000\133\000\134\000\
    \255\255\047\001\047\001\047\001\047\001\047\001\047\001\047\001\
    \047\001\047\001\047\001\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\047\001\134\000\
    \255\255\255\255\255\255\255\255\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\047\001\255\255\
    \255\255\255\255\134\000\255\255\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\134\000\134\000\
    \134\000\134\000\134\000\134\000\134\000\134\000\135\000\049\001\
    \049\001\049\001\049\001\049\001\049\001\049\001\049\001\049\001\
    \049\001\255\255\135\000\135\000\135\000\135\000\135\000\135\000\
    \135\000\135\000\135\000\135\000\135\000\255\255\135\000\255\255\
    \255\255\255\255\255\255\135\000\135\000\135\000\135\000\135\000\
    \135\000\135\000\135\000\135\000\135\000\135\000\135\000\135\000\
    \135\000\135\000\135\000\135\000\135\000\135\000\135\000\135\000\
    \135\000\135\000\135\000\135\000\135\000\255\255\255\255\255\255\
    \255\255\135\000\255\255\135\000\135\000\135\000\135\000\135\000\
    \135\000\135\000\135\000\135\000\135\000\135\000\135\000\135\000\
    \135\000\135\000\135\000\135\000\135\000\135\000\135\000\135\000\
    \135\000\135\000\135\000\135\000\135\000\136\000\050\001\050\001\
    \050\001\050\001\050\001\050\001\050\001\050\001\050\001\050\001\
    \255\255\136\000\136\000\136\000\136\000\136\000\136\000\136\000\
    \136\000\136\000\136\000\136\000\255\255\136\000\255\255\255\255\
    \255\255\255\255\136\000\136\000\136\000\136\000\136\000\136\000\
    \136\000\136\000\136\000\136\000\136\000\136\000\136\000\136\000\
    \136\000\136\000\136\000\136\000\136\000\136\000\136\000\136\000\
    \136\000\136\000\136\000\136\000\255\255\255\255\255\255\255\255\
    \136\000\255\255\136\000\136\000\136\000\136\000\136\000\136\000\
    \136\000\136\000\136\000\136\000\136\000\136\000\136\000\136\000\
    \136\000\136\000\136\000\136\000\136\000\136\000\136\000\136\000\
    \136\000\136\000\136\000\136\000\137\000\255\255\109\001\109\001\
    \109\001\109\001\109\001\109\001\109\001\109\001\109\001\109\001\
    \137\000\137\000\137\000\137\000\137\000\137\000\137\000\137\000\
    \137\000\137\000\137\000\109\001\137\000\151\001\151\001\151\001\
    \151\001\137\000\137\000\137\000\137\000\137\000\137\000\137\000\
    \137\000\137\000\137\000\137\000\137\000\137\000\137\000\137\000\
    \137\000\137\000\137\000\137\000\137\000\137\000\137\000\137\000\
    \137\000\137\000\137\000\109\001\255\255\151\001\151\001\137\000\
    \255\255\137\000\137\000\137\000\137\000\137\000\137\000\137\000\
    \137\000\137\000\137\000\137\000\137\000\137\000\137\000\137\000\
    \137\000\137\000\137\000\137\000\137\000\137\000\137\000\137\000\
    \137\000\137\000\137\000\138\000\113\001\113\001\113\001\113\001\
    \113\001\113\001\113\001\113\001\113\001\113\001\255\255\138\000\
    \138\000\138\000\138\000\138\000\138\000\138\000\138\000\138\000\
    \138\000\138\000\255\255\138\000\255\255\255\255\255\255\255\255\
    \138\000\138\000\138\000\138\000\138\000\138\000\138\000\138\000\
    \138\000\138\000\138\000\138\000\138\000\138\000\138\000\138\000\
    \138\000\138\000\138\000\138\000\138\000\138\000\138\000\138\000\
    \138\000\138\000\255\255\255\255\255\255\255\255\138\000\255\255\
    \138\000\138\000\138\000\138\000\138\000\138\000\138\000\138\000\
    \138\000\138\000\138\000\138\000\138\000\138\000\138\000\138\000\
    \138\000\138\000\138\000\138\000\138\000\138\000\138\000\138\000\
    \138\000\138\000\139\000\114\001\114\001\114\001\114\001\114\001\
    \114\001\114\001\114\001\114\001\114\001\255\255\139\000\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \139\000\255\255\139\000\255\255\255\255\255\255\255\255\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \139\000\255\255\255\255\255\255\255\255\139\000\255\255\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \139\000\139\000\139\000\139\000\139\000\139\000\139\000\139\000\
    \139\000\140\000\124\001\124\001\124\001\124\001\124\001\124\001\
    \124\001\124\001\255\255\151\001\255\255\140\000\140\000\140\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \255\255\140\000\255\255\255\255\255\255\255\255\140\000\140\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \255\255\255\255\255\255\255\255\140\000\255\255\140\000\140\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
    \141\000\134\001\134\001\134\001\134\001\134\001\134\001\134\001\
    \134\001\255\255\255\255\255\255\141\000\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\141\000\141\000\141\000\255\255\
    \141\000\255\255\255\255\255\255\255\255\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\141\000\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\141\000\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\141\000\141\000\141\000\255\255\
    \255\255\255\255\255\255\141\000\255\255\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\141\000\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\141\000\141\000\141\000\141\000\
    \141\000\141\000\141\000\141\000\141\000\141\000\141\000\142\000\
    \135\001\135\001\135\001\135\001\135\001\135\001\135\001\135\001\
    \255\255\255\255\255\255\142\000\142\000\142\000\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\255\255\142\000\
    \255\255\255\255\255\255\255\255\142\000\142\000\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\255\255\255\255\
    \255\255\255\255\142\000\255\255\142\000\142\000\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\142\000\142\000\
    \142\000\142\000\142\000\142\000\142\000\142\000\143\000\146\001\
    \146\001\146\001\146\001\146\001\146\001\146\001\146\001\255\255\
    \255\255\255\255\143\000\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\143\000\143\000\143\000\255\255\143\000\255\255\
    \255\255\255\255\255\255\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\143\000\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\143\000\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\143\000\143\000\143\000\255\255\255\255\255\255\
    \255\255\143\000\255\255\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\143\000\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\143\000\143\000\143\000\143\000\143\000\143\000\
    \143\000\143\000\143\000\143\000\143\000\144\000\147\001\147\001\
    \147\001\147\001\147\001\147\001\147\001\147\001\255\255\255\255\
    \255\255\144\000\144\000\144\000\144\000\144\000\144\000\144\000\
    \144\000\144\000\144\000\144\000\255\255\144\000\255\255\255\255\
    \255\255\255\255\144\000\144\000\144\000\144\000\144\000\144\000\
    \144\000\144\000\144\000\144\000\144\000\144\000\144\000\144\000\
    \144\000\144\000\144\000\144\000\144\000\144\000\144\000\144\000\
    \144\000\144\000\144\000\144\000\255\255\255\255\255\255\255\255\
    \144\000\255\255\144\000\144\000\144\000\144\000\144\000\144\000\
    \144\000\144\000\144\000\144\000\144\000\144\000\144\000\144\000\
    \144\000\144\000\144\000\144\000\144\000\144\000\144\000\144\000\
    \144\000\144\000\144\000\144\000\145\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\255\255\255\255\255\255\255\255\145\000\255\255\
    \255\255\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\255\255\255\255\255\255\255\255\145\000\
    \255\255\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\145\000\145\000\145\000\145\000\145\000\
    \145\000\145\000\145\000\147\000\255\255\110\001\145\000\110\001\
    \255\255\255\255\110\001\110\001\110\001\110\001\110\001\110\001\
    \110\001\110\001\110\001\110\001\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
    \147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
    \147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
    \147\000\147\000\255\255\255\255\255\255\255\255\147\000\255\255\
    \147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
    \147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
    \147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
    \147\000\147\000\148\000\255\255\255\255\147\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\255\255\148\000\255\255\255\255\255\255\255\255\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\255\255\255\255\255\255\149\000\148\000\255\255\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
    \148\000\149\000\149\000\149\000\149\000\149\000\149\000\149\000\
    \149\000\149\000\149\000\149\000\149\000\149\000\149\000\149\000\
    \149\000\149\000\149\000\149\000\149\000\149\000\149\000\149\000\
    \149\000\149\000\149\000\255\255\255\255\255\255\255\255\149\000\
    \255\255\149\000\149\000\149\000\149\000\149\000\149\000\149\000\
    \149\000\149\000\149\000\149\000\149\000\149\000\149\000\149\000\
    \149\000\149\000\149\000\149\000\149\000\149\000\149\000\149\000\
    \149\000\149\000\149\000\150\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\255\255\150\000\255\255\255\255\255\255\255\255\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\255\255\255\255\255\255\151\000\150\000\255\255\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
    \150\000\150\000\151\000\151\000\151\000\151\000\151\000\151\000\
    \151\000\151\000\151\000\151\000\151\000\151\000\151\000\151\000\
    \151\000\151\000\151\000\151\000\151\000\151\000\151\000\151\000\
    \151\000\151\000\151\000\151\000\255\255\255\255\255\255\255\255\
    \151\000\255\255\151\000\151\000\151\000\151\000\151\000\151\000\
    \151\000\151\000\151\000\151\000\151\000\151\000\151\000\151\000\
    \151\000\151\000\151\000\151\000\151\000\151\000\151\000\151\000\
    \151\000\151\000\151\000\151\000\154\000\255\255\255\255\151\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\255\255\255\255\255\255\255\255\154\000\255\255\
    \255\255\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\128\001\255\255\255\255\255\255\154\000\
    \255\255\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
    \154\000\154\000\154\000\157\000\255\255\111\001\154\000\111\001\
    \111\001\111\001\111\001\111\001\111\001\111\001\111\001\111\001\
    \111\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \128\001\255\255\255\255\255\255\111\001\255\255\255\255\255\255\
    \157\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
    \157\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
    \157\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
    \157\000\157\000\255\255\255\255\111\001\255\255\157\000\255\255\
    \157\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
    \157\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
    \157\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
    \157\000\157\000\158\000\255\255\255\255\157\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \255\255\255\255\255\255\255\255\158\000\255\255\255\255\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\255\255\255\255\255\255\255\255\158\000\255\255\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
    \158\000\160\000\255\255\255\255\158\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\128\001\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\160\000\160\000\
    \160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
    \160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
    \160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
    \255\255\255\255\255\255\255\255\160\000\255\255\160\000\160\000\
    \160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
    \160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
    \160\000\160\000\160\000\160\000\160\000\160\000\160\000\160\000\
    \161\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\255\255\
    \161\000\255\255\255\255\255\255\255\255\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\255\255\
    \255\255\255\255\162\000\161\000\255\255\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\162\000\
    \162\000\162\000\162\000\162\000\162\000\162\000\162\000\162\000\
    \162\000\162\000\162\000\162\000\162\000\162\000\162\000\162\000\
    \162\000\162\000\162\000\162\000\162\000\162\000\162\000\162\000\
    \162\000\255\255\255\255\255\255\255\255\162\000\255\255\162\000\
    \162\000\162\000\162\000\162\000\162\000\162\000\162\000\162\000\
    \162\000\162\000\162\000\162\000\162\000\162\000\162\000\162\000\
    \162\000\162\000\162\000\162\000\162\000\162\000\162\000\162\000\
    \162\000\163\000\255\255\255\255\162\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\255\255\
    \255\255\255\255\255\255\163\000\255\255\255\255\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \255\255\255\255\255\255\255\255\163\000\255\255\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \165\000\255\255\255\255\163\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\165\000\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\165\000\165\000\255\255\
    \165\000\255\255\255\255\255\255\255\255\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\165\000\165\000\255\255\
    \255\255\255\255\255\255\165\000\255\255\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\165\000\165\000\165\000\
    \165\000\165\000\165\000\165\000\165\000\165\000\165\000\166\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\166\000\166\000\166\000\166\000\166\000\
    \166\000\166\000\166\000\166\000\166\000\166\000\255\255\166\000\
    \255\255\255\255\255\255\255\255\166\000\166\000\166\000\166\000\
    \166\000\166\000\166\000\166\000\166\000\166\000\166\000\166\000\
    \166\000\166\000\166\000\166\000\166\000\166\000\166\000\166\000\
    \166\000\166\000\166\000\166\000\166\000\166\000\255\255\255\255\
    \255\255\255\255\166\000\255\255\166\000\166\000\166\000\166\000\
    \166\000\166\000\166\000\166\000\166\000\166\000\166\000\166\000\
    \166\000\166\000\166\000\166\000\166\000\166\000\166\000\166\000\
    \166\000\166\000\166\000\166\000\166\000\166\000\167\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\255\255\167\000\255\255\
    \255\255\255\255\255\255\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\255\255\255\255\255\255\
    \255\255\167\000\255\255\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\167\000\167\000\167\000\
    \167\000\167\000\167\000\167\000\167\000\168\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\255\255\168\000\255\255\255\255\
    \255\255\255\255\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\255\255\255\255\255\255\255\255\
    \168\000\255\255\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\168\000\168\000\168\000\169\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\255\255\169\000\255\255\255\255\255\255\
    \255\255\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\255\255\255\255\255\255\223\000\169\000\
    \255\255\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\223\000\223\000\223\000\223\000\223\000\
    \223\000\223\000\223\000\223\000\223\000\223\000\223\000\223\000\
    \223\000\223\000\223\000\223\000\223\000\223\000\223\000\223\000\
    \223\000\223\000\223\000\223\000\223\000\255\255\255\255\255\255\
    \255\255\223\000\255\255\223\000\223\000\223\000\223\000\223\000\
    \223\000\223\000\223\000\223\000\223\000\223\000\223\000\223\000\
    \223\000\223\000\223\000\223\000\223\000\223\000\223\000\223\000\
    \223\000\223\000\223\000\223\000\223\000\224\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\255\255\224\000\255\255\255\255\
    \255\255\255\255\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\255\255\255\255\255\255\226\000\
    \224\000\255\255\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\226\000\226\000\226\000\226\000\
    \226\000\226\000\226\000\226\000\226\000\226\000\226\000\226\000\
    \226\000\226\000\226\000\226\000\226\000\226\000\226\000\226\000\
    \226\000\226\000\226\000\226\000\226\000\226\000\255\255\255\255\
    \255\255\255\255\226\000\255\255\226\000\226\000\226\000\226\000\
    \226\000\226\000\226\000\226\000\226\000\226\000\226\000\226\000\
    \226\000\226\000\226\000\226\000\226\000\226\000\226\000\226\000\
    \226\000\226\000\226\000\226\000\226\000\226\000\227\000\255\255\
    \255\255\226\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\255\255\255\255\255\255\255\255\
    \227\000\255\255\255\255\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\255\255\255\255\255\255\
    \255\255\227\000\255\255\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\227\000\227\000\227\000\
    \227\000\227\000\227\000\227\000\227\000\229\000\255\255\255\255\
    \227\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\229\000\229\000\229\000\229\000\229\000\229\000\
    \229\000\229\000\229\000\229\000\229\000\229\000\229\000\229\000\
    \229\000\229\000\229\000\229\000\229\000\229\000\229\000\229\000\
    \229\000\229\000\229\000\229\000\255\255\255\255\255\255\255\255\
    \229\000\255\255\229\000\229\000\229\000\229\000\229\000\229\000\
    \229\000\229\000\229\000\229\000\229\000\229\000\229\000\229\000\
    \229\000\229\000\229\000\229\000\229\000\229\000\229\000\229\000\
    \229\000\229\000\229\000\229\000\230\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\255\255\230\000\255\255\255\255\255\255\
    \255\255\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\255\255\255\255\255\255\231\000\230\000\
    \255\255\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\231\000\231\000\231\000\231\000\231\000\
    \231\000\231\000\231\000\231\000\231\000\231\000\231\000\231\000\
    \231\000\231\000\231\000\231\000\231\000\231\000\231\000\231\000\
    \231\000\231\000\231\000\231\000\231\000\255\255\255\255\255\255\
    \255\255\231\000\255\255\231\000\231\000\231\000\231\000\231\000\
    \231\000\231\000\231\000\231\000\231\000\231\000\231\000\231\000\
    \231\000\231\000\231\000\231\000\231\000\231\000\231\000\231\000\
    \231\000\231\000\231\000\231\000\231\000\232\000\255\255\255\255\
    \231\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\255\255\255\255\255\255\255\255\232\000\
    \255\255\255\255\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\255\255\255\255\255\255\255\255\
    \232\000\255\255\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\232\000\232\000\232\000\232\000\
    \232\000\232\000\232\000\232\000\239\000\255\255\239\000\232\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\239\000\239\000\239\000\239\000\239\000\239\000\
    \239\000\239\000\239\000\239\000\239\000\255\255\239\000\255\255\
    \255\255\255\255\255\255\239\000\239\000\239\000\239\000\239\000\
    \239\000\239\000\239\000\239\000\239\000\239\000\239\000\239\000\
    \239\000\239\000\239\000\239\000\239\000\239\000\239\000\239\000\
    \239\000\239\000\239\000\239\000\239\000\255\255\255\255\255\255\
    \255\255\239\000\255\255\239\000\239\000\239\000\239\000\239\000\
    \239\000\239\000\239\000\239\000\239\000\239\000\239\000\239\000\
    \239\000\239\000\239\000\239\000\239\000\239\000\239\000\239\000\
    \239\000\239\000\239\000\239\000\239\000\244\000\244\000\244\000\
    \244\000\244\000\244\000\244\000\244\000\244\000\244\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\244\000\244\000\
    \244\000\244\000\244\000\244\000\255\255\255\255\248\000\255\255\
    \248\000\248\000\248\000\248\000\248\000\248\000\248\000\248\000\
    \248\000\248\000\255\255\139\001\139\001\139\001\139\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\248\000\244\000\244\000\
    \244\000\244\000\244\000\244\000\248\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\139\001\255\255\248\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\248\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\248\000\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\248\000\251\000\251\000\
    \251\000\251\000\251\000\251\000\251\000\251\000\251\000\251\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\251\000\
    \251\000\251\000\251\000\251\000\251\000\139\001\255\255\255\255\
    \255\255\255\255\251\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\251\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\251\000\
    \251\000\251\000\251\000\251\000\251\000\255\000\255\000\255\000\
    \255\000\255\000\251\000\255\255\255\255\120\001\255\255\255\255\
    \255\255\255\255\255\255\251\000\130\001\130\001\130\001\130\001\
    \130\001\130\001\130\001\130\001\255\000\255\000\255\000\255\000\
    \255\000\255\000\255\000\255\000\255\000\255\000\255\000\255\000\
    \255\000\255\000\255\000\255\000\255\000\255\000\255\000\255\000\
    \255\000\255\000\255\000\255\000\255\000\255\000\255\000\255\000\
    \255\000\255\000\255\000\255\255\255\000\255\000\255\000\255\000\
    \255\000\255\000\255\000\255\000\255\000\255\000\255\000\255\000\
    \255\000\255\000\255\000\255\000\255\000\255\000\255\000\255\000\
    \255\000\255\000\255\000\255\000\255\000\255\000\255\000\255\000\
    \255\255\255\000\255\000\255\000\130\001\255\000\255\000\255\000\
    \255\000\255\000\255\000\255\000\255\000\255\000\255\000\255\000\
    \255\000\255\000\255\000\255\000\255\000\255\000\255\000\255\000\
    \255\000\255\000\255\000\255\000\255\000\255\000\255\000\255\000\
    \255\000\255\000\001\001\255\255\001\001\001\001\001\001\001\001\
    \001\001\001\001\001\001\001\001\001\001\001\001\255\255\255\255\
    \255\255\139\001\255\255\255\255\255\255\255\255\255\255\255\255\
    \001\001\001\001\255\255\255\255\255\255\120\001\255\255\255\255\
    \001\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \002\001\001\001\002\001\002\001\002\001\002\001\002\001\002\001\
    \002\001\002\001\002\001\002\001\255\255\255\255\255\255\255\255\
    \001\001\001\001\255\255\255\255\255\255\255\255\002\001\002\001\
    \001\001\255\255\255\255\255\255\255\255\255\255\002\001\255\255\
    \255\255\001\001\255\255\255\255\255\255\255\255\255\255\002\001\
    \255\255\255\255\002\001\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\002\001\002\001\
    \255\255\255\255\255\255\255\255\255\255\255\255\002\001\255\255\
    \005\001\255\255\255\255\255\255\130\001\255\255\255\255\002\001\
    \255\255\255\255\002\001\255\255\005\001\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\005\001\255\255\
    \005\001\255\255\255\255\255\255\255\000\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\005\001\255\255\
    \255\255\255\255\255\255\005\001\255\255\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\005\001\005\001\
    \005\001\005\001\005\001\005\001\005\001\005\001\005\001\006\001\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\255\255\006\001\
    \255\255\255\255\255\255\255\255\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\255\255\255\255\
    \255\255\255\255\006\001\255\255\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\006\001\006\001\
    \006\001\006\001\006\001\006\001\006\001\006\001\007\001\255\255\
    \007\001\255\255\255\255\007\001\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\007\001\007\001\007\001\007\001\
    \007\001\007\001\007\001\007\001\007\001\007\001\007\001\255\255\
    \007\001\255\255\255\255\255\255\255\255\007\001\007\001\007\001\
    \007\001\007\001\007\001\007\001\007\001\007\001\007\001\007\001\
    \007\001\007\001\007\001\007\001\007\001\007\001\007\001\007\001\
    \007\001\007\001\007\001\007\001\007\001\007\001\007\001\255\255\
    \255\255\255\255\255\255\007\001\255\255\007\001\007\001\007\001\
    \007\001\007\001\007\001\007\001\007\001\007\001\007\001\007\001\
    \007\001\007\001\007\001\007\001\007\001\007\001\007\001\007\001\
    \007\001\007\001\007\001\007\001\007\001\007\001\007\001\008\001\
    \255\255\008\001\255\255\255\255\008\001\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\008\001\008\001\008\001\
    \008\001\008\001\008\001\008\001\008\001\008\001\008\001\008\001\
    \255\255\008\001\255\255\255\255\255\255\255\255\008\001\008\001\
    \008\001\008\001\008\001\008\001\008\001\008\001\008\001\008\001\
    \008\001\008\001\008\001\008\001\008\001\008\001\008\001\008\001\
    \008\001\008\001\008\001\008\001\008\001\008\001\008\001\008\001\
    \255\255\255\255\255\255\255\255\008\001\255\255\008\001\008\001\
    \008\001\008\001\008\001\008\001\008\001\008\001\008\001\008\001\
    \008\001\008\001\008\001\008\001\008\001\008\001\008\001\008\001\
    \008\001\008\001\008\001\008\001\008\001\008\001\008\001\008\001\
    \009\001\255\255\009\001\255\255\255\255\009\001\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\009\001\009\001\
    \009\001\009\001\009\001\009\001\009\001\009\001\009\001\009\001\
    \009\001\255\255\009\001\255\255\255\255\255\255\255\255\009\001\
    \009\001\009\001\009\001\009\001\009\001\009\001\009\001\009\001\
    \009\001\009\001\009\001\009\001\009\001\009\001\009\001\009\001\
    \009\001\009\001\009\001\009\001\009\001\009\001\009\001\009\001\
    \009\001\255\255\255\255\255\255\065\001\009\001\255\255\009\001\
    \009\001\009\001\009\001\009\001\009\001\009\001\009\001\009\001\
    \009\001\009\001\009\001\009\001\009\001\009\001\009\001\009\001\
    \009\001\009\001\009\001\009\001\009\001\009\001\009\001\009\001\
    \009\001\065\001\065\001\065\001\065\001\065\001\065\001\065\001\
    \065\001\065\001\065\001\065\001\065\001\065\001\065\001\065\001\
    \065\001\065\001\065\001\065\001\065\001\065\001\065\001\065\001\
    \065\001\065\001\065\001\255\255\255\255\255\255\255\255\065\001\
    \255\255\065\001\065\001\065\001\065\001\065\001\065\001\065\001\
    \065\001\065\001\065\001\065\001\065\001\065\001\065\001\065\001\
    \065\001\065\001\065\001\065\001\065\001\065\001\065\001\065\001\
    \065\001\065\001\065\001\066\001\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\255\255\066\001\255\255\255\255\255\255\255\255\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\255\255\255\255\255\255\068\001\066\001\255\255\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\066\001\066\001\066\001\066\001\066\001\066\001\
    \066\001\066\001\068\001\068\001\068\001\068\001\068\001\068\001\
    \068\001\068\001\068\001\068\001\068\001\068\001\068\001\068\001\
    \068\001\068\001\068\001\068\001\068\001\068\001\068\001\068\001\
    \068\001\068\001\068\001\068\001\255\255\255\255\255\255\255\255\
    \068\001\255\255\068\001\068\001\068\001\068\001\068\001\068\001\
    \068\001\068\001\068\001\068\001\068\001\068\001\068\001\068\001\
    \068\001\068\001\068\001\068\001\068\001\068\001\068\001\068\001\
    \068\001\068\001\068\001\068\001\069\001\255\255\255\255\068\001\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\255\255\255\255\255\255\255\255\069\001\255\255\
    \255\255\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\255\255\255\255\255\255\255\255\069\001\
    \255\255\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
    \069\001\069\001\069\001\071\001\255\255\255\255\069\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \071\001\071\001\071\001\071\001\071\001\071\001\071\001\071\001\
    \071\001\071\001\071\001\071\001\071\001\071\001\071\001\071\001\
    \071\001\071\001\071\001\071\001\071\001\071\001\071\001\071\001\
    \071\001\071\001\255\255\255\255\255\255\255\255\071\001\255\255\
    \071\001\071\001\071\001\071\001\071\001\071\001\071\001\071\001\
    \071\001\071\001\071\001\071\001\071\001\071\001\071\001\071\001\
    \071\001\071\001\071\001\071\001\071\001\071\001\071\001\071\001\
    \071\001\071\001\072\001\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\255\255\072\001\255\255\255\255\255\255\255\255\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\255\255\255\255\255\255\073\001\072\001\255\255\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\072\001\072\001\072\001\072\001\072\001\072\001\072\001\
    \072\001\073\001\073\001\073\001\073\001\073\001\073\001\073\001\
    \073\001\073\001\073\001\073\001\073\001\073\001\073\001\073\001\
    \073\001\073\001\073\001\073\001\073\001\073\001\073\001\073\001\
    \073\001\073\001\073\001\255\255\255\255\255\255\255\255\073\001\
    \255\255\073\001\073\001\073\001\073\001\073\001\073\001\073\001\
    \073\001\073\001\073\001\073\001\073\001\073\001\073\001\073\001\
    \073\001\073\001\073\001\073\001\073\001\073\001\073\001\073\001\
    \073\001\073\001\073\001\074\001\255\255\255\255\073\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\255\255\255\255\255\255\255\255\074\001\255\255\255\255\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\255\255\255\255\255\255\255\255\074\001\255\255\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\074\001\074\001\074\001\074\001\074\001\074\001\
    \074\001\074\001\079\001\255\255\255\255\074\001\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\141\001\
    \141\001\141\001\141\001\141\001\141\001\141\001\141\001\079\001\
    \079\001\079\001\079\001\079\001\079\001\079\001\079\001\079\001\
    \079\001\079\001\079\001\079\001\079\001\079\001\079\001\079\001\
    \079\001\079\001\079\001\079\001\079\001\079\001\079\001\079\001\
    \079\001\255\255\255\255\255\255\255\255\079\001\255\255\079\001\
    \079\001\079\001\079\001\079\001\079\001\079\001\079\001\079\001\
    \079\001\079\001\079\001\079\001\079\001\079\001\079\001\079\001\
    \079\001\079\001\079\001\079\001\079\001\079\001\079\001\079\001\
    \079\001\080\001\255\255\255\255\079\001\255\255\255\255\141\001\
    \255\255\255\255\255\255\255\255\255\255\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\255\255\
    \255\255\255\255\255\255\080\001\255\255\255\255\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \255\255\255\255\255\255\255\255\080\001\255\255\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \080\001\080\001\080\001\080\001\080\001\080\001\080\001\080\001\
    \082\001\255\255\255\255\080\001\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\082\001\082\001\082\001\
    \082\001\082\001\082\001\082\001\082\001\082\001\082\001\082\001\
    \082\001\082\001\082\001\082\001\082\001\082\001\082\001\082\001\
    \082\001\082\001\082\001\082\001\082\001\082\001\082\001\141\001\
    \255\255\255\255\255\255\082\001\255\255\082\001\082\001\082\001\
    \082\001\082\001\082\001\082\001\082\001\082\001\082\001\082\001\
    \082\001\082\001\082\001\082\001\082\001\082\001\082\001\082\001\
    \082\001\082\001\082\001\082\001\082\001\082\001\082\001\083\001\
    \255\255\255\255\082\001\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\255\255\083\001\
    \255\255\255\255\255\255\255\255\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\255\255\255\255\
    \255\255\084\001\083\001\255\255\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
    \083\001\083\001\083\001\083\001\083\001\083\001\084\001\084\001\
    \084\001\084\001\084\001\084\001\084\001\084\001\084\001\084\001\
    \084\001\084\001\084\001\084\001\084\001\084\001\084\001\084\001\
    \084\001\084\001\084\001\084\001\084\001\084\001\084\001\084\001\
    \255\255\255\255\255\255\255\255\084\001\255\255\084\001\084\001\
    \084\001\084\001\084\001\084\001\084\001\084\001\084\001\084\001\
    \084\001\084\001\084\001\084\001\084\001\084\001\084\001\084\001\
    \084\001\084\001\084\001\084\001\084\001\084\001\084\001\084\001\
    \085\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\255\255\
    \085\001\255\255\255\255\255\255\255\255\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\255\255\
    \255\255\255\255\086\001\085\001\255\255\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
    \085\001\085\001\085\001\085\001\085\001\085\001\085\001\086\001\
    \086\001\086\001\086\001\086\001\086\001\086\001\086\001\086\001\
    \086\001\086\001\086\001\086\001\086\001\086\001\086\001\086\001\
    \086\001\086\001\086\001\086\001\086\001\086\001\086\001\086\001\
    \086\001\255\255\255\255\255\255\255\255\086\001\255\255\086\001\
    \086\001\086\001\086\001\086\001\086\001\086\001\086\001\086\001\
    \086\001\086\001\086\001\086\001\086\001\086\001\086\001\086\001\
    \086\001\086\001\086\001\086\001\086\001\086\001\086\001\086\001\
    \086\001\089\001\255\255\255\255\086\001\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\255\255\
    \255\255\255\255\255\255\089\001\255\255\255\255\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \255\255\255\255\255\255\255\255\089\001\255\255\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \089\001\089\001\089\001\089\001\089\001\089\001\089\001\089\001\
    \092\001\255\255\255\255\089\001\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\092\001\092\001\092\001\
    \092\001\092\001\092\001\092\001\092\001\092\001\092\001\092\001\
    \092\001\092\001\092\001\092\001\092\001\092\001\092\001\092\001\
    \092\001\092\001\092\001\092\001\092\001\092\001\092\001\255\255\
    \255\255\255\255\255\255\092\001\255\255\092\001\092\001\092\001\
    \092\001\092\001\092\001\092\001\092\001\092\001\092\001\092\001\
    \092\001\092\001\092\001\092\001\092\001\092\001\092\001\092\001\
    \092\001\092\001\092\001\092\001\092\001\092\001\092\001\093\001\
    \255\255\255\255\092\001\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\255\255\255\255\255\255\
    \255\255\093\001\255\255\255\255\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\255\255\255\255\
    \255\255\255\255\093\001\255\255\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\095\001\255\255\
    \255\255\093\001\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\095\001\095\001\095\001\095\001\095\001\
    \095\001\095\001\095\001\095\001\095\001\095\001\095\001\095\001\
    \095\001\095\001\095\001\095\001\095\001\095\001\095\001\095\001\
    \095\001\095\001\095\001\095\001\095\001\255\255\255\255\255\255\
    \255\255\095\001\255\255\095\001\095\001\095\001\095\001\095\001\
    \095\001\095\001\095\001\095\001\095\001\095\001\095\001\095\001\
    \095\001\095\001\095\001\095\001\095\001\095\001\095\001\095\001\
    \095\001\095\001\095\001\095\001\095\001\096\001\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\255\255\096\001\255\255\255\255\
    \255\255\255\255\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\255\255\255\255\255\255\097\001\
    \096\001\255\255\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\097\001\097\001\097\001\097\001\
    \097\001\097\001\097\001\097\001\097\001\097\001\097\001\097\001\
    \097\001\097\001\097\001\097\001\097\001\097\001\097\001\097\001\
    \097\001\097\001\097\001\097\001\097\001\097\001\255\255\255\255\
    \255\255\255\255\097\001\255\255\097\001\097\001\097\001\097\001\
    \097\001\097\001\097\001\097\001\097\001\097\001\097\001\097\001\
    \097\001\097\001\097\001\097\001\097\001\097\001\097\001\097\001\
    \097\001\097\001\097\001\097\001\097\001\097\001\098\001\255\255\
    \255\255\097\001\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\255\255\255\255\255\255\255\255\
    \098\001\255\255\255\255\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\255\255\255\255\255\255\
    \255\255\098\001\255\255\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\098\001\098\001\103\001\255\255\103\001\
    \098\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\103\001\103\001\103\001\103\001\103\001\
    \103\001\103\001\103\001\103\001\103\001\103\001\255\255\103\001\
    \255\255\255\255\255\255\255\255\103\001\103\001\103\001\103\001\
    \103\001\103\001\103\001\103\001\103\001\103\001\103\001\103\001\
    \103\001\103\001\103\001\103\001\103\001\103\001\103\001\103\001\
    \103\001\103\001\103\001\103\001\103\001\103\001\255\255\255\255\
    \255\255\255\255\103\001\255\255\103\001\103\001\103\001\103\001\
    \103\001\103\001\103\001\103\001\103\001\103\001\103\001\103\001\
    \103\001\103\001\103\001\103\001\103\001\103\001\103\001\103\001\
    \103\001\103\001\103\001\103\001\103\001\103\001\108\001\108\001\
    \108\001\108\001\108\001\108\001\108\001\108\001\108\001\108\001\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\108\001\
    \108\001\108\001\108\001\108\001\108\001\255\255\255\255\112\001\
    \255\255\112\001\112\001\112\001\112\001\112\001\112\001\112\001\
    \112\001\112\001\112\001\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\112\001\108\001\
    \108\001\108\001\108\001\108\001\108\001\112\001\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\112\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\112\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\112\001\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\112\001\115\001\
    \115\001\115\001\115\001\115\001\115\001\115\001\115\001\115\001\
    \115\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \115\001\115\001\115\001\115\001\115\001\115\001\255\255\255\255\
    \255\255\255\255\255\255\115\001\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\115\001\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \115\001\115\001\115\001\115\001\115\001\115\001\255\255\255\255\
    \255\255\255\255\255\255\115\001\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\115\001\122\001\122\001\122\001\
    \122\001\122\001\122\001\122\001\122\001\122\001\122\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\122\001\122\001\
    \122\001\122\001\122\001\122\001\126\001\126\001\126\001\126\001\
    \126\001\126\001\126\001\126\001\126\001\126\001\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\126\001\126\001\126\001\
    \126\001\126\001\126\001\255\255\255\255\255\255\122\001\122\001\
    \122\001\122\001\122\001\122\001\255\255\255\255\255\255\255\255\
    \255\255\255\255\133\001\133\001\133\001\133\001\133\001\133\001\
    \133\001\133\001\133\001\133\001\255\255\126\001\126\001\126\001\
    \126\001\126\001\126\001\133\001\133\001\133\001\133\001\133\001\
    \133\001\137\001\137\001\137\001\137\001\137\001\137\001\137\001\
    \137\001\137\001\137\001\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\137\001\137\001\137\001\137\001\137\001\137\001\
    \255\255\255\255\255\255\133\001\133\001\133\001\133\001\133\001\
    \133\001\255\255\255\255\255\255\255\255\255\255\255\255\145\001\
    \145\001\145\001\145\001\145\001\145\001\145\001\145\001\145\001\
    \145\001\255\255\137\001\137\001\137\001\137\001\137\001\137\001\
    \145\001\145\001\145\001\145\001\145\001\145\001\149\001\149\001\
    \149\001\149\001\149\001\149\001\149\001\149\001\149\001\149\001\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\149\001\
    \149\001\149\001\149\001\149\001\149\001\255\255\255\255\255\255\
    \145\001\145\001\145\001\145\001\145\001\145\001\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\149\001\
    \149\001\149\001\149\001\149\001\149\001\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255";
  Lexing.lex_base_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\001\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\002\000\003\000\
    \000\000\000\000\000\000\000\000\000\000\004\000\005\000\000\000\
    \043\000\000\000\000\000\000\000\000\000\006\000\038\000\152\000\
    \007\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_backtrk_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\008\000\000\000\
    \000\000\011\000\000\000\000\000\000\000\000\000\014\000\014\000\
    \014\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \023\000\000\000\000\000\000\000\000\000\000\000\000\000\038\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \060\000\060\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_default_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_trans_code =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\001\000\001\000\020\000\020\000\033\000\033\000\051\000\
    \057\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \001\000\001\000\020\000\020\000\033\000\033\000\051\000\057\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\051\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\051\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\048\000\000\000\000\000\000\000\028\000\017\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\000\000\000\000\000\000\000\000\054\000\000\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\057\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \057\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\000\000\000\000\000\000\000\000\054\000\
    \000\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000";
  Lexing.lex_check_code =
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\043\000\070\000\071\000\077\000\078\000\085\000\
    \088\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\043\000\070\000\071\000\077\000\078\000\085\000\088\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\086\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\086\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\084\000\255\255\255\255\255\255\076\000\069\000\086\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\255\255\255\255\255\255\255\255\086\000\255\255\086\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\087\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \087\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\255\255\255\255\255\255\255\255\087\000\
    \255\255\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255";
  Lexing.lex_code =
   "\255\006\255\005\255\004\255\255\000\004\255\000\005\255\000\006\
    \255\007\255\255\008\255\255\000\007\001\008\255\010\255\009\255\
    \255\012\255\011\255\255\000\009\001\011\255\000\010\001\012\255\
    \013\255\255\014\255\255\015\255\255\016\255\255\003\016\001\014\
    \000\013\002\015\255";
}

let rec token lexbuf =
  lexbuf.Lexing.lex_mem <- Array.make 17 (-1);(* L=3 [6] <- p ; [5] <- p ; [4] <- p ;  *)
  lexbuf.Lexing.lex_mem.(6) <- lexbuf.Lexing.lex_curr_pos ;
  lexbuf.Lexing.lex_mem.(5) <- lexbuf.Lexing.lex_curr_pos ;
  lexbuf.Lexing.lex_mem.(4) <- lexbuf.Lexing.lex_curr_pos ;
 __ocaml_lex_token_rec lexbuf 0
and __ocaml_lex_token_rec lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 637 "parsing_cocci/lexer_cocci.mll"
    ( let cls = !current_line_started in
      if not cls
      then
	begin
	  match !current_line_type with
	    (D.PLUS,_,_) | (D.PLUSPLUS,_,_) ->
	      (* increment the logical line even though nothing seen *)
	      start_line true;
	      let info = get_current_line_type lexbuf in
	      reset_line lexbuf;
	      TDirective (Ast.Noindent "", info)
	  | _ -> reset_line lexbuf; token lexbuf
	end
      else (reset_line lexbuf; token lexbuf) )
# 3081 "parsing_cocci/lexer_cocci.ml"

  | 1 ->
let
# 652 "parsing_cocci/lexer_cocci.mll"
                      w
# 3087 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 652 "parsing_cocci/lexer_cocci.mll"
                         ( (* collect whitespaces only when inside a rule *)
    start_line false;
    if !Data.in_rule_name || !Data.in_prolog || !Data.in_iso
    then token lexbuf
    else TWhitespace w )
# 3095 "parsing_cocci/lexer_cocci.ml"

  | 2 ->
let
# 658 "parsing_cocci/lexer_cocci.mll"
                                       after
# 3101 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) lexbuf.Lexing.lex_curr_pos in
# 658 "parsing_cocci/lexer_cocci.mll"
                                              (
    match !current_line_type with
      (D.PLUS,_,_) | (D.PLUSPLUS,_,_) ->
	let str =
	  if !current_line_started
	  then (tok lexbuf)
	  else after in
	start_line true;
	TDirective (Ast.Indent str, get_current_line_type lexbuf)
    | _ -> start_line false; token lexbuf )
# 3114 "parsing_cocci/lexer_cocci.ml"

  | 3 ->
let
# 669 "parsing_cocci/lexer_cocci.mll"
                                       after
# 3120 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) lexbuf.Lexing.lex_curr_pos in
# 669 "parsing_cocci/lexer_cocci.mll"
                                              (
     check_context_linetype after;
     start_line false; token lexbuf )
# 3126 "parsing_cocci/lexer_cocci.ml"

  | 4 ->
let
# 673 "parsing_cocci/lexer_cocci.mll"
                                                                                   spatch
# 3132 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) lexbuf.Lexing.lex_curr_pos in
# 673 "parsing_cocci/lexer_cocci.mll"
                                                                                           (
     check_context_linetype spatch;
     start_line false; token lexbuf )
# 3138 "parsing_cocci/lexer_cocci.ml"

  | 5 ->
# 678 "parsing_cocci/lexer_cocci.mll"
   ( match !current_line_type with
      (D.PLUS,_,_) | (D.PLUSPLUS,_,_) ->
	start_line true;
	TAttr_ (get_current_line_type lexbuf)
    | _ -> failwith "attributes only allowed in + code" )
# 3147 "parsing_cocci/lexer_cocci.ml"

  | 6 ->
# 684 "parsing_cocci/lexer_cocci.mll"
         ( start_line true; TArobArob )
# 3152 "parsing_cocci/lexer_cocci.ml"

  | 7 ->
# 685 "parsing_cocci/lexer_cocci.mll"
         ( pass_zero();
	   if !Data.in_rule_name || not !current_line_started
	   then (start_line true; TArob)
	   else (check_minus_context_linetype "@";
		 TPArob (get_current_line_type lexbuf)) )
# 3161 "parsing_cocci/lexer_cocci.ml"

  | 8 ->
# 692 "parsing_cocci/lexer_cocci.mll"
      ( start_line true; check_minus_context_linetype (tok lexbuf);
	TWhen (get_current_line_type lexbuf) )
# 3167 "parsing_cocci/lexer_cocci.ml"

  | 9 ->
# 696 "parsing_cocci/lexer_cocci.mll"
      ( start_line true; check_minus_context_linetype (tok lexbuf);
	TEllipsis (get_current_line_type lexbuf) )
# 3173 "parsing_cocci/lexer_cocci.ml"

  | 10 ->
# 698 "parsing_cocci/lexer_cocci.mll"
           ( start_line true; check_context_linetype (tok lexbuf);
	     TOEllipsis (get_current_line_type lexbuf) )
# 3179 "parsing_cocci/lexer_cocci.ml"

  | 11 ->
# 700 "parsing_cocci/lexer_cocci.mll"
           ( start_line true; check_context_linetype (tok lexbuf);
	     TCEllipsis (get_current_line_type lexbuf) )
# 3185 "parsing_cocci/lexer_cocci.ml"

  | 12 ->
# 702 "parsing_cocci/lexer_cocci.mll"
            ( start_line true; check_minus_context_linetype (tok lexbuf);
	     TPOEllipsis (get_current_line_type lexbuf) )
# 3191 "parsing_cocci/lexer_cocci.ml"

  | 13 ->
# 704 "parsing_cocci/lexer_cocci.mll"
            ( start_line true; check_minus_context_linetype (tok lexbuf);
	     TPCEllipsis (get_current_line_type lexbuf) )
# 3197 "parsing_cocci/lexer_cocci.ml"

  | 14 ->
# 706 "parsing_cocci/lexer_cocci.mll"
        ( pass_zero();
	  if !current_line_started
	  then (start_line true; TMinus (get_current_line_type lexbuf))
          else (patch_or_match PATCH;
		add_current_line_type D.MINUS; token lexbuf) )
# 3206 "parsing_cocci/lexer_cocci.ml"

  | 15 ->
# 711 "parsing_cocci/lexer_cocci.mll"
        ( pass_zero();
	  if !current_line_started
	  then (start_line true; TPlus (get_current_line_type lexbuf))
          else (patch_or_match PATCH;
		add_current_line_type D.PLUS; token lexbuf) )
# 3215 "parsing_cocci/lexer_cocci.ml"

  | 16 ->
# 716 "parsing_cocci/lexer_cocci.mll"
        ( pass_zero();
	  if !current_line_started
	  then (start_line true; TWhy (get_current_line_type lexbuf))
          else (add_current_line_type D.OPT; token lexbuf) )
# 3223 "parsing_cocci/lexer_cocci.ml"

  | 17 ->
# 720 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TBang (get_current_line_type lexbuf) )
# 3228 "parsing_cocci/lexer_cocci.ml"

  | 18 ->
# 721 "parsing_cocci/lexer_cocci.mll"
        ( if not !col_zero
	  then (start_line true; TOPar (get_current_line_type lexbuf))
          else
            (start_line true; check_context_linetype (tok lexbuf);
	     TOPar0 ("(",get_current_line_type lexbuf)))
# 3237 "parsing_cocci/lexer_cocci.ml"

  | 19 ->
# 726 "parsing_cocci/lexer_cocci.mll"
          ( start_line true;
	    TOPar0 ("\\(",contextify(get_current_line_type lexbuf)) )
# 3243 "parsing_cocci/lexer_cocci.ml"

  | 20 ->
# 728 "parsing_cocci/lexer_cocci.mll"
        ( if not (!col_zero)
	  then (start_line true; TOr(get_current_line_type lexbuf))
          else (start_line true;
		check_context_linetype (tok lexbuf);
		TMid0 ("|",get_current_line_type lexbuf)))
# 3252 "parsing_cocci/lexer_cocci.ml"

  | 21 ->
# 733 "parsing_cocci/lexer_cocci.mll"
          ( start_line true;
	    TMid0 ("\\|",contextify(get_current_line_type lexbuf)) )
# 3258 "parsing_cocci/lexer_cocci.ml"

  | 22 ->
# 735 "parsing_cocci/lexer_cocci.mll"
        ( if not !col_zero
	  then (start_line true; TCPar (get_current_line_type lexbuf))
          else
            (start_line true; check_context_linetype (tok lexbuf);
	     TCPar0 (")",get_current_line_type lexbuf)))
# 3267 "parsing_cocci/lexer_cocci.ml"

  | 23 ->
# 740 "parsing_cocci/lexer_cocci.mll"
          ( start_line true;
	    TCPar0 ("\\)",contextify(get_current_line_type lexbuf)) )
# 3273 "parsing_cocci/lexer_cocci.ml"

  | 24 ->
# 743 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TOCro (get_current_line_type lexbuf)   )
# 3278 "parsing_cocci/lexer_cocci.ml"

  | 25 ->
# 744 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TCCro (get_current_line_type lexbuf)   )
# 3283 "parsing_cocci/lexer_cocci.ml"

  | 26 ->
# 745 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TOBrace (get_current_line_type lexbuf) )
# 3288 "parsing_cocci/lexer_cocci.ml"

  | 27 ->
# 746 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TCBrace (get_current_line_type lexbuf) )
# 3293 "parsing_cocci/lexer_cocci.ml"

  | 28 ->
# 748 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TPtrOp (get_current_line_type lexbuf)  )
# 3298 "parsing_cocci/lexer_cocci.ml"

  | 29 ->
# 749 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TDot (get_current_line_type lexbuf)    )
# 3303 "parsing_cocci/lexer_cocci.ml"

  | 30 ->
# 750 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TComma (get_current_line_type lexbuf)  )
# 3308 "parsing_cocci/lexer_cocci.ml"

  | 31 ->
# 751 "parsing_cocci/lexer_cocci.mll"
               ( start_line true; TVAEllipsis (get_current_line_type lexbuf) )
# 3313 "parsing_cocci/lexer_cocci.ml"

  | 32 ->
# 752 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TPtVirg (get_current_line_type lexbuf) )
# 3318 "parsing_cocci/lexer_cocci.ml"

  | 33 ->
# 755 "parsing_cocci/lexer_cocci.mll"
                   ( pass_zero();
		     if !current_line_started
		     then
		       (start_line true; TMul (get_current_line_type lexbuf))
		     else
		       (patch_or_match MATCH;
			add_current_line_type D.MINUS; token lexbuf) )
# 3329 "parsing_cocci/lexer_cocci.ml"

  | 34 ->
# 762 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;
		     TDmOp (Ast.Div,get_current_line_type lexbuf) )
# 3335 "parsing_cocci/lexer_cocci.ml"

  | 35 ->
# 764 "parsing_cocci/lexer_cocci.mll"
                    ( start_line true;
		     TDmOp (Ast.Min,get_current_line_type lexbuf) )
# 3341 "parsing_cocci/lexer_cocci.ml"

  | 36 ->
# 766 "parsing_cocci/lexer_cocci.mll"
                    ( start_line true;
		     TDmOp (Ast.Max,get_current_line_type lexbuf) )
# 3347 "parsing_cocci/lexer_cocci.ml"

  | 37 ->
# 768 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;
		     TDmOp (Ast.Mod,get_current_line_type lexbuf) )
# 3353 "parsing_cocci/lexer_cocci.ml"

  | 38 ->
# 770 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;  TTilde (get_current_line_type lexbuf) )
# 3358 "parsing_cocci/lexer_cocci.ml"

  | 39 ->
# 772 "parsing_cocci/lexer_cocci.mll"
                   ( pass_zero();
 		     if !current_line_started
 		     then
 		       (start_line true; TInc (get_current_line_type lexbuf))
 		     else (patch_or_match PATCH;
 			   add_current_line_type D.PLUSPLUS; token lexbuf) )
# 3368 "parsing_cocci/lexer_cocci.ml"

  | 40 ->
# 778 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;  TDec (get_current_line_type lexbuf) )
# 3373 "parsing_cocci/lexer_cocci.ml"

  | 41 ->
# 780 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TEq (get_current_line_type lexbuf) )
# 3378 "parsing_cocci/lexer_cocci.ml"

  | 42 ->
# 782 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Minus lexbuf )
# 3383 "parsing_cocci/lexer_cocci.ml"

  | 43 ->
# 783 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Plus lexbuf )
# 3388 "parsing_cocci/lexer_cocci.ml"

  | 44 ->
# 785 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Mul lexbuf )
# 3393 "parsing_cocci/lexer_cocci.ml"

  | 45 ->
# 786 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Div lexbuf )
# 3398 "parsing_cocci/lexer_cocci.ml"

  | 46 ->
# 787 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Mod lexbuf )
# 3403 "parsing_cocci/lexer_cocci.ml"

  | 47 ->
# 789 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.And lexbuf )
# 3408 "parsing_cocci/lexer_cocci.ml"

  | 48 ->
# 790 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Or lexbuf )
# 3413 "parsing_cocci/lexer_cocci.ml"

  | 49 ->
# 791 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Xor lexbuf )
# 3418 "parsing_cocci/lexer_cocci.ml"

  | 50 ->
# 792 "parsing_cocci/lexer_cocci.mll"
                    ( start_line true; mkassign Ast.Max lexbuf )
# 3423 "parsing_cocci/lexer_cocci.ml"

  | 51 ->
# 793 "parsing_cocci/lexer_cocci.mll"
                    ( start_line true; mkassign Ast.Min lexbuf )
# 3428 "parsing_cocci/lexer_cocci.ml"

  | 52 ->
# 795 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.DecLeft lexbuf )
# 3433 "parsing_cocci/lexer_cocci.ml"

  | 53 ->
# 796 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.DecRight lexbuf )
# 3438 "parsing_cocci/lexer_cocci.ml"

  | 54 ->
# 798 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TDotDot (get_current_line_type lexbuf) )
# 3443 "parsing_cocci/lexer_cocci.ml"

  | 55 ->
# 800 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TEqEq    (get_current_line_type lexbuf) )
# 3448 "parsing_cocci/lexer_cocci.ml"

  | 56 ->
# 801 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TNotEq   (get_current_line_type lexbuf) )
# 3453 "parsing_cocci/lexer_cocci.ml"

  | 57 ->
# 802 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;
		     TLogOp(Ast.SupEq,get_current_line_type lexbuf) )
# 3459 "parsing_cocci/lexer_cocci.ml"

  | 58 ->
# 804 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;
		     TLogOp(Ast.InfEq,get_current_line_type lexbuf) )
# 3465 "parsing_cocci/lexer_cocci.ml"

  | 59 ->
# 806 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;
		     TLogOp(Ast.Inf,get_current_line_type lexbuf) )
# 3471 "parsing_cocci/lexer_cocci.ml"

  | 60 ->
# 808 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;
		     TLogOp(Ast.Sup,get_current_line_type lexbuf) )
# 3477 "parsing_cocci/lexer_cocci.ml"

  | 61 ->
# 811 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TAndLog (get_current_line_type lexbuf) )
# 3482 "parsing_cocci/lexer_cocci.ml"

  | 62 ->
# 812 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TOrLog  (get_current_line_type lexbuf) )
# 3487 "parsing_cocci/lexer_cocci.ml"

  | 63 ->
# 814 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;
		     TShROp(Ast.DecRight,get_current_line_type lexbuf) )
# 3493 "parsing_cocci/lexer_cocci.ml"

  | 64 ->
# 816 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;
		     TShLOp(Ast.DecLeft,get_current_line_type lexbuf) )
# 3499 "parsing_cocci/lexer_cocci.ml"

  | 65 ->
# 819 "parsing_cocci/lexer_cocci.mll"
                   ( if not (!col_zero)
                     then (start_line true; TAnd(get_current_line_type lexbuf))
                     else (start_line true;
	                   check_context_linetype (tok lexbuf);
		           TAnd0 ("&",get_current_line_type lexbuf)))
# 3508 "parsing_cocci/lexer_cocci.ml"

  | 66 ->
# 824 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;
	             TAnd0 ("\\&",contextify(get_current_line_type lexbuf)) )
# 3514 "parsing_cocci/lexer_cocci.ml"

  | 67 ->
# 827 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TXor(get_current_line_type lexbuf) )
# 3519 "parsing_cocci/lexer_cocci.ml"

  | 68 ->
# 829 "parsing_cocci/lexer_cocci.mll"
                    ( start_line true; TCppConcatOp )
# 3524 "parsing_cocci/lexer_cocci.ml"

  | 69 ->
let
# 830 "parsing_cocci/lexer_cocci.mll"
                                               wss
# 3530 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) lexbuf.Lexing.lex_mem.(1)
and
# 830 "parsing_cocci/lexer_cocci.mll"
                                                        def
# 3535 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(1)
and
# 831 "parsing_cocci/lexer_cocci.mll"
                                  ident
# 3540 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(1) lexbuf.Lexing.lex_curr_pos in
# 832 "parsing_cocci/lexer_cocci.mll"
      ( start_line true;
	let (arity,line,lline,llend,offset,col,strbef,straft,pos,ws) as lt =
	  get_current_line_type lexbuf in
	let off = String.length def in
	(* -1 in the code below because the ident is not at the line start *)
	TUndef
	  (lt,
	   check_var ident
	     (arity,line,lline,llend,offset+off,col+off,[],[],[],wss)) )
# 3552 "parsing_cocci/lexer_cocci.ml"

  | 70 ->
let
# 841 "parsing_cocci/lexer_cocci.mll"
                                                  wss
# 3558 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) lexbuf.Lexing.lex_mem.(1)
and
# 841 "parsing_cocci/lexer_cocci.mll"
                                                            def
# 3563 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(1)
and
# 842 "parsing_cocci/lexer_cocci.mll"
                                   ident
# 3568 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(1) lexbuf.Lexing.lex_curr_pos in
# 843 "parsing_cocci/lexer_cocci.mll"
      ( start_line true;
	let (arity,line,lline,llend,offset,col,strbef,straft,pos,ws) as lt =
	  get_current_line_type lexbuf in
	let off = String.length def in
	(* -1 in the code below because the ident is not at the line start *)
	TDefine
	  (lt,
	   check_var ident
	     (arity,line,lline,llend,offset+off,col+off,[],[],[],wss)) )
# 3580 "parsing_cocci/lexer_cocci.ml"

  | 71 ->
let
# 852 "parsing_cocci/lexer_cocci.mll"
                                                  wss
# 3586 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) lexbuf.Lexing.lex_mem.(1)
and
# 852 "parsing_cocci/lexer_cocci.mll"
                                                            def
# 3591 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(1)
and
# 853 "parsing_cocci/lexer_cocci.mll"
                                    ident
# 3596 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(1) (lexbuf.Lexing.lex_curr_pos + -1) in
# 855 "parsing_cocci/lexer_cocci.mll"
      ( start_line true;
	let (arity,line,lline,llend,offset,col,strbef,straft,pos,ws) as lt =
	  get_current_line_type lexbuf in
	let off = String.length def in
	TDefineParam
        (lt,
	 check_var ident
	   (* why pos here but not above? *)
	   (arity,line,lline,llend,offset+off,col+off,strbef,straft,pos,wss),
	 offset + off + (String.length ident),
	 col + off + (String.length ident)) )
# 3610 "parsing_cocci/lexer_cocci.ml"

  | 72 ->
let
# 866 "parsing_cocci/lexer_cocci.mll"
                                    prag
# 3616 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_mem.(0)
and
# 866 "parsing_cocci/lexer_cocci.mll"
                                                          wss1
# 3621 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) lexbuf.Lexing.lex_mem.(1)
and
# 867 "parsing_cocci/lexer_cocci.mll"
                                    ident
# 3626 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(1) lexbuf.Lexing.lex_mem.(2)
and
# 867 "parsing_cocci/lexer_cocci.mll"
                                                           wss2
# 3631 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(2) lexbuf.Lexing.lex_mem.(3)
and
# 867 "parsing_cocci/lexer_cocci.mll"
                                                                               rest
# 3636 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(3) lexbuf.Lexing.lex_curr_pos in
# 868 "parsing_cocci/lexer_cocci.mll"
      ( start_line true;
	let (arity,line,lline,llend,offset,col,strbef,straft,pos,ws) as lt =
	  get_current_line_type lexbuf in
	let off1 = String.length prag + String.length wss1 in
	let off2 = off1 + String.length ident + String.length wss2 in
	TPragma(lt,
		check_var ident
	        (* why pos here but not above? *)
		  (arity,line,lline,llend,offset+off1,col+off1,strbef,straft,
		   pos,wss1),
		rest,
		(arity,line,lline,llend,offset+off2,col+off2,strbef,straft,
		 pos,wss2)) )
# 3652 "parsing_cocci/lexer_cocci.ml"

  | 73 ->
# 884 "parsing_cocci/lexer_cocci.mll"
      ( TIncludeL
	  (let str = tok lexbuf in
	  let start = String.index str '\"' in
	  let finish = String.rindex str '\"' in
	  start_line true;
	  (process_include start finish str, get_current_line_type lexbuf)) )
# 3662 "parsing_cocci/lexer_cocci.ml"

  | 74 ->
# 891 "parsing_cocci/lexer_cocci.mll"
      ( TIncludeNL
	  (let str = tok lexbuf in
	  let start = String.index str '<' in
	  let finish = String.rindex str '>' in
	  start_line true;
	  (process_include start finish str,get_current_line_type lexbuf)) )
# 3672 "parsing_cocci/lexer_cocci.ml"

  | 75 ->
# 898 "parsing_cocci/lexer_cocci.mll"
      ( check_minus_context_linetype (tok lexbuf);
	start_line true;
	TIncludeAny("...",get_current_line_type lexbuf) )
# 3679 "parsing_cocci/lexer_cocci.ml"

  | 76 ->
# 902 "parsing_cocci/lexer_cocci.mll"
      ( check_context_linetype (tok lexbuf);
	start_line true;
	TInclude(get_current_line_type lexbuf) )
# 3686 "parsing_cocci/lexer_cocci.ml"

  | 77 ->
# 913 "parsing_cocci/lexer_cocci.mll"
      ( start_line true; check_plus_linetype (tok lexbuf);
	TDirective (Ast.Noindent(tok lexbuf), get_current_line_type lexbuf) )
# 3692 "parsing_cocci/lexer_cocci.ml"

  | 78 ->
# 917 "parsing_cocci/lexer_cocci.mll"
      ( start_line true;
	let res = TCppEscapedNewline (get_current_line_type lexbuf) in
	reset_line lexbuf;
	res )
# 3700 "parsing_cocci/lexer_cocci.ml"

  | 79 ->
# 923 "parsing_cocci/lexer_cocci.mll"
      (
       match !current_line_type with
        (D.PLUS,_,_) | (D.PLUSPLUS,_,_) ->
        start_line true;
	(* second argument to TDirective is not quite right, because
	   it represents only the first token of the comment, but that
	   should be good enough *)
	TDirective (Ast.Indent("/*"^(comment check_comment lexbuf)),
		 get_current_line_type lexbuf)
      |	_ -> let _ = comment (fun _ -> ()) lexbuf in token lexbuf )
# 3714 "parsing_cocci/lexer_cocci.ml"

  | 80 ->
# 934 "parsing_cocci/lexer_cocci.mll"
      ( (if !current_line_started
      then lexerr "--- must be at the beginning of the line" "");
	start_line true;
	TMinusFile
	  (let str = tok lexbuf in
	  (drop_spaces(String.sub str 3 (String.length str - 3)),
	   (get_current_line_type lexbuf))) )
# 3725 "parsing_cocci/lexer_cocci.ml"

  | 81 ->
# 942 "parsing_cocci/lexer_cocci.mll"
      ( (if !current_line_started
      then lexerr "+++ must be at the beginning of the line" "");
	start_line true;
	TPlusFile
	  (let str = tok lexbuf in
	  (drop_spaces(String.sub str 3 (String.length str - 3)),
	   (get_current_line_type lexbuf))) )
# 3736 "parsing_cocci/lexer_cocci.ml"

  | 82 ->
# 951 "parsing_cocci/lexer_cocci.mll"
      ( start_line true; id_tokens lexbuf )
# 3741 "parsing_cocci/lexer_cocci.ml"

  | 83 ->
# 955 "parsing_cocci/lexer_cocci.mll"
      ( start_line true; id_tokens lexbuf )
# 3746 "parsing_cocci/lexer_cocci.ml"

  | 84 ->
# 962 "parsing_cocci/lexer_cocci.mll"
      (
	start_line true;
	if !Flag.c_plus_plus = Flag.Off
	then
	  Common.pr2_once
	    "< and > not allowed in C identifiers, try -c++ option";
	id_tokens lexbuf
      )
# 3758 "parsing_cocci/lexer_cocci.ml"

  | 85 ->
# 973 "parsing_cocci/lexer_cocci.mll"
      (
	start_line true;
	if !Flag.c_plus_plus = Flag.Off
	then
	  Common.pr2_once
	    "< and > not allowed in C identifiers, try -c++ option";
	id_tokens lexbuf
      )
# 3770 "parsing_cocci/lexer_cocci.ml"

  | 86 ->
# 989 "parsing_cocci/lexer_cocci.mll"
      (
	start_line true;
	if !Flag.c_plus_plus = Flag.Off
	then
	  Common.pr2_once
	    "~ and :: not allowed in C identifiers, try -c++ option";
	id_tokens lexbuf
      )
# 3782 "parsing_cocci/lexer_cocci.ml"

  | 87 ->
# 1002 "parsing_cocci/lexer_cocci.mll"
      (
	start_line true;
	if !Flag.c_plus_plus = Flag.Off
	then
	  Common.pr2_once
	    "~ and :: not allowed in C identifiers, try -c++ option";
	id_tokens lexbuf
      )
# 3794 "parsing_cocci/lexer_cocci.ml"

  | 88 ->
# 1013 "parsing_cocci/lexer_cocci.mll"
        ( start_line true;
	  TChar(char lexbuf,Ast.IsChar,get_current_line_type lexbuf) )
# 3800 "parsing_cocci/lexer_cocci.ml"

  | 89 ->
# 1015 "parsing_cocci/lexer_cocci.mll"
         ( start_line true;
	  TString(string lexbuf,Ast.IsChar,(get_current_line_type lexbuf)) )
# 3806 "parsing_cocci/lexer_cocci.ml"

  | 90 ->
# 1017 "parsing_cocci/lexer_cocci.mll"
            ( start_line true;
	  TChar(char lexbuf,Ast.IsWchar,get_current_line_type lexbuf) )
# 3812 "parsing_cocci/lexer_cocci.ml"

  | 91 ->
# 1019 "parsing_cocci/lexer_cocci.mll"
             ( start_line true;
	  TString(string lexbuf,Ast.IsWchar,(get_current_line_type lexbuf)) )
# 3818 "parsing_cocci/lexer_cocci.ml"

  | 92 ->
# 1021 "parsing_cocci/lexer_cocci.mll"
            ( start_line true;
	  TChar(char lexbuf,Ast.IsUchar,get_current_line_type lexbuf) )
# 3824 "parsing_cocci/lexer_cocci.ml"

  | 93 ->
# 1023 "parsing_cocci/lexer_cocci.mll"
             ( start_line true;
	  TString(string lexbuf,Ast.IsUchar,(get_current_line_type lexbuf)) )
# 3830 "parsing_cocci/lexer_cocci.ml"

  | 94 ->
# 1025 "parsing_cocci/lexer_cocci.mll"
            ( start_line true;
	  TChar(char lexbuf,Ast.Isuchar,get_current_line_type lexbuf) )
# 3836 "parsing_cocci/lexer_cocci.ml"

  | 95 ->
# 1027 "parsing_cocci/lexer_cocci.mll"
             ( start_line true;
	  TString(string lexbuf,Ast.Isuchar,(get_current_line_type lexbuf)) )
# 3842 "parsing_cocci/lexer_cocci.ml"

  | 96 ->
# 1029 "parsing_cocci/lexer_cocci.mll"
              ( start_line true;
	  TString(string lexbuf,Ast.Isu8char,(get_current_line_type lexbuf)) )
# 3848 "parsing_cocci/lexer_cocci.ml"

  | 97 ->
let
# 1031 "parsing_cocci/lexer_cocci.mll"
             x
# 3854 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 1031 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;
		     TFloat(x,(get_current_line_type lexbuf)) )
# 3859 "parsing_cocci/lexer_cocci.ml"

  | 98 ->
let
# 1042 "parsing_cocci/lexer_cocci.mll"
         x
# 3865 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 1042 "parsing_cocci/lexer_cocci.mll"
            ( start_line true; TInt(x,(get_current_line_type lexbuf)) )
# 3869 "parsing_cocci/lexer_cocci.ml"

  | 99 ->
let
# 1044 "parsing_cocci/lexer_cocci.mll"
                           x
# 3875 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 1045 "parsing_cocci/lexer_cocci.mll"
      ( if !Flag.ibm
      then
	begin
	  start_line true;
	  let len = string_of_int(String.length x - 1) in
          TDecimalCst(x,len,"0",(get_current_line_type lexbuf))
	end
      else failwith "unrecognized constant modifier d/D" )
# 3886 "parsing_cocci/lexer_cocci.ml"

  | 100 ->
# 1054 "parsing_cocci/lexer_cocci.mll"
                   ( TIso )
# 3891 "parsing_cocci/lexer_cocci.ml"

  | 101 ->
# 1055 "parsing_cocci/lexer_cocci.mll"
                   ( TRightIso )
# 3896 "parsing_cocci/lexer_cocci.ml"

  | 102 ->
# 1057 "parsing_cocci/lexer_cocci.mll"
                   ( EOF )
# 3901 "parsing_cocci/lexer_cocci.ml"

  | 103 ->
# 1059 "parsing_cocci/lexer_cocci.mll"
      ( lexerr "unrecognised symbol, in token rule: " (tok lexbuf) )
# 3906 "parsing_cocci/lexer_cocci.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_token_rec lexbuf __ocaml_lex_state

and metavariable_decl_token lexbuf =
   __ocaml_lex_metavariable_decl_token_rec lexbuf 255
and __ocaml_lex_metavariable_decl_token_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 1064 "parsing_cocci/lexer_cocci.mll"
    ( reset_line lexbuf; metavariable_decl_token lexbuf )
# 3918 "parsing_cocci/lexer_cocci.ml"

  | 1 ->
# 1066 "parsing_cocci/lexer_cocci.mll"
                  (
    start_line false; metavariable_decl_token lexbuf )
# 3924 "parsing_cocci/lexer_cocci.ml"

  | 2 ->
# 1069 "parsing_cocci/lexer_cocci.mll"
                                   (
    start_line false; metavariable_decl_token lexbuf )
# 3930 "parsing_cocci/lexer_cocci.ml"

  | 3 ->
# 1072 "parsing_cocci/lexer_cocci.mll"
         ( start_line true; TArobArob )
# 3935 "parsing_cocci/lexer_cocci.ml"

  | 4 ->
# 1074 "parsing_cocci/lexer_cocci.mll"
         ( start_line true; TTildeEq (get_current_line_type lexbuf) )
# 3940 "parsing_cocci/lexer_cocci.ml"

  | 5 ->
# 1075 "parsing_cocci/lexer_cocci.mll"
         ( start_line true; TTildeExclEq (get_current_line_type lexbuf) )
# 3945 "parsing_cocci/lexer_cocci.ml"

  | 6 ->
# 1076 "parsing_cocci/lexer_cocci.mll"
         ( start_line true; TEq (get_current_line_type lexbuf) )
# 3950 "parsing_cocci/lexer_cocci.ml"

  | 7 ->
# 1077 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TOPar (get_current_line_type lexbuf) )
# 3955 "parsing_cocci/lexer_cocci.ml"

  | 8 ->
# 1078 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TCPar (get_current_line_type lexbuf) )
# 3960 "parsing_cocci/lexer_cocci.ml"

  | 9 ->
# 1080 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TOCro (get_current_line_type lexbuf)   )
# 3965 "parsing_cocci/lexer_cocci.ml"

  | 10 ->
# 1081 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TCCro (get_current_line_type lexbuf)   )
# 3970 "parsing_cocci/lexer_cocci.ml"

  | 11 ->
# 1082 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TOBrace (get_current_line_type lexbuf) )
# 3975 "parsing_cocci/lexer_cocci.ml"

  | 12 ->
# 1083 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TCBrace (get_current_line_type lexbuf) )
# 3980 "parsing_cocci/lexer_cocci.ml"

  | 13 ->
# 1085 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TPtrOp (get_current_line_type lexbuf)  )
# 3985 "parsing_cocci/lexer_cocci.ml"

  | 14 ->
# 1086 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TDot (get_current_line_type lexbuf)    )
# 3990 "parsing_cocci/lexer_cocci.ml"

  | 15 ->
# 1087 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TComma (get_current_line_type lexbuf)  )
# 3995 "parsing_cocci/lexer_cocci.ml"

  | 16 ->
# 1088 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;
		     TMPtVirg (* works better with tokens_all *) )
# 4001 "parsing_cocci/lexer_cocci.ml"

  | 17 ->
# 1090 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true;
		     TShLOp(Ast.DecLeft,get_current_line_type lexbuf) )
# 4007 "parsing_cocci/lexer_cocci.ml"

  | 18 ->
# 1093 "parsing_cocci/lexer_cocci.mll"
                   ( pass_zero();
		     if !current_line_started
		     then
		       (start_line true; TMul (get_current_line_type lexbuf))
		     else
		       (patch_or_match MATCH;
			add_current_line_type D.MINUS;
			metavariable_decl_token lexbuf) )
# 4019 "parsing_cocci/lexer_cocci.ml"

  | 19 ->
# 1102 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TEqEq    (get_current_line_type lexbuf) )
# 4024 "parsing_cocci/lexer_cocci.ml"

  | 20 ->
# 1103 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TNotEq   (get_current_line_type lexbuf) )
# 4029 "parsing_cocci/lexer_cocci.ml"

  | 21 ->
# 1104 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; TSub     (get_current_line_type lexbuf) )
# 4034 "parsing_cocci/lexer_cocci.ml"

  | 22 ->
# 1105 "parsing_cocci/lexer_cocci.mll"
        ( (start_line true; TPlus (get_current_line_type lexbuf)) )
# 4039 "parsing_cocci/lexer_cocci.ml"

  | 23 ->
# 1106 "parsing_cocci/lexer_cocci.mll"
        ( (start_line true; TMinus (get_current_line_type lexbuf)) )
# 4044 "parsing_cocci/lexer_cocci.ml"

  | 24 ->
# 1107 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TDmOp (Ast.Div,get_current_line_type lexbuf) )
# 4049 "parsing_cocci/lexer_cocci.ml"

  | 25 ->
# 1108 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TDmOp (Ast.Mod,get_current_line_type lexbuf) )
# 4054 "parsing_cocci/lexer_cocci.ml"

  | 26 ->
# 1109 "parsing_cocci/lexer_cocci.mll"
         ( start_line true; TShROp(Ast.DecRight,get_current_line_type lexbuf) )
# 4059 "parsing_cocci/lexer_cocci.ml"

  | 27 ->
# 1110 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TAnd (get_current_line_type lexbuf) )
# 4064 "parsing_cocci/lexer_cocci.ml"

  | 28 ->
# 1111 "parsing_cocci/lexer_cocci.mll"
        (  (start_line true; TOr(get_current_line_type lexbuf)) )
# 4069 "parsing_cocci/lexer_cocci.ml"

  | 29 ->
# 1112 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TXor(get_current_line_type lexbuf) )
# 4074 "parsing_cocci/lexer_cocci.ml"

  | 30 ->
# 1113 "parsing_cocci/lexer_cocci.mll"
         ( start_line true; TLogOp(Ast.SupEq,get_current_line_type lexbuf) )
# 4079 "parsing_cocci/lexer_cocci.ml"

  | 31 ->
# 1114 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TLogOp(Ast.Inf,get_current_line_type lexbuf) )
# 4084 "parsing_cocci/lexer_cocci.ml"

  | 32 ->
# 1115 "parsing_cocci/lexer_cocci.mll"
        ( start_line true; TLogOp(Ast.Sup,get_current_line_type lexbuf) )
# 4089 "parsing_cocci/lexer_cocci.ml"

  | 33 ->
# 1116 "parsing_cocci/lexer_cocci.mll"
         ( start_line true; TAndLog (get_current_line_type lexbuf) )
# 4094 "parsing_cocci/lexer_cocci.ml"

  | 34 ->
# 1117 "parsing_cocci/lexer_cocci.mll"
         ( start_line true; TOrLog (get_current_line_type lexbuf) )
# 4099 "parsing_cocci/lexer_cocci.ml"

  | 35 ->
# 1118 "parsing_cocci/lexer_cocci.mll"
         ( start_line true; TDotDot (get_current_line_type lexbuf) )
# 4104 "parsing_cocci/lexer_cocci.ml"

  | 36 ->
# 1119 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Minus lexbuf )
# 4109 "parsing_cocci/lexer_cocci.ml"

  | 37 ->
# 1120 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Plus lexbuf )
# 4114 "parsing_cocci/lexer_cocci.ml"

  | 38 ->
# 1121 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Mul lexbuf )
# 4119 "parsing_cocci/lexer_cocci.ml"

  | 39 ->
# 1122 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Div lexbuf )
# 4124 "parsing_cocci/lexer_cocci.ml"

  | 40 ->
# 1123 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Mod lexbuf )
# 4129 "parsing_cocci/lexer_cocci.ml"

  | 41 ->
# 1124 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.And lexbuf )
# 4134 "parsing_cocci/lexer_cocci.ml"

  | 42 ->
# 1125 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Or lexbuf )
# 4139 "parsing_cocci/lexer_cocci.ml"

  | 43 ->
# 1126 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.Xor lexbuf )
# 4144 "parsing_cocci/lexer_cocci.ml"

  | 44 ->
# 1127 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.DecLeft lexbuf )
# 4149 "parsing_cocci/lexer_cocci.ml"

  | 45 ->
# 1128 "parsing_cocci/lexer_cocci.mll"
                   ( start_line true; mkassign Ast.DecRight lexbuf )
# 4154 "parsing_cocci/lexer_cocci.ml"

  | 46 ->
# 1130 "parsing_cocci/lexer_cocci.mll"
      (match !current_line_type with
        (D.PLUS,_,_) | (D.PLUSPLUS,_,_) ->
        start_line true;
	(* second argument to TDirective is not quite right, because
	   it represents only the first token of the comment, but that
	   should be good enough *)
	TDirective (Ast.Indent("/*"^(comment check_comment lexbuf)),
		 get_current_line_type lexbuf)
      |	_ -> let _ = comment (fun _ -> ()) lexbuf in
	     metavariable_decl_token lexbuf )
# 4168 "parsing_cocci/lexer_cocci.ml"

  | 47 ->
# 1141 "parsing_cocci/lexer_cocci.mll"
                    ( start_line true; TCppConcatOp (* for fresh vars *) )
# 4173 "parsing_cocci/lexer_cocci.ml"

  | 48 ->
# 1144 "parsing_cocci/lexer_cocci.mll"
      ( start_line true; id_tokens lexbuf )
# 4178 "parsing_cocci/lexer_cocci.ml"

  | 49 ->
# 1148 "parsing_cocci/lexer_cocci.mll"
      ( start_line true; id_tokens lexbuf )
# 4183 "parsing_cocci/lexer_cocci.ml"

  | 50 ->
# 1155 "parsing_cocci/lexer_cocci.mll"
      ( start_line true;
	if !Flag.c_plus_plus = Flag.Off
	then
	  Common.pr2_once
	    "< and > not allowed in C identifiers, try -c++ option";
	id_tokens lexbuf
      )
# 4194 "parsing_cocci/lexer_cocci.ml"

  | 51 ->
# 1165 "parsing_cocci/lexer_cocci.mll"
      ( start_line true;
	if !Flag.c_plus_plus = Flag.Off
	then
	  Common.pr2_once
	    "< and > not allowed in C identifiers, try -c++ option";
	id_tokens lexbuf
      )
# 4205 "parsing_cocci/lexer_cocci.ml"

  | 52 ->
# 1180 "parsing_cocci/lexer_cocci.mll"
      ( start_line true;
	if !Flag.c_plus_plus = Flag.Off
	then
	  Common.pr2_once
	    "~ and :: not allowed in C identifiers, try -c++ option";
	id_tokens lexbuf
      )
# 4216 "parsing_cocci/lexer_cocci.ml"

  | 53 ->
# 1192 "parsing_cocci/lexer_cocci.mll"
      ( start_line true;
	if !Flag.c_plus_plus = Flag.Off
	then
	  Common.pr2_once
	    "~ and :: not allowed in C identifiers, try -c++ option";
	id_tokens lexbuf
      )
# 4227 "parsing_cocci/lexer_cocci.ml"

  | 54 ->
# 1202 "parsing_cocci/lexer_cocci.mll"
        ( start_line true;
	  TChar(char lexbuf,Ast.IsChar,get_current_line_type lexbuf) )
# 4233 "parsing_cocci/lexer_cocci.ml"

  | 55 ->
# 1204 "parsing_cocci/lexer_cocci.mll"
         ( start_line true;
	  TString(string lexbuf,Ast.IsChar,(get_current_line_type lexbuf)) )
# 4239 "parsing_cocci/lexer_cocci.ml"

  | 56 ->
# 1206 "parsing_cocci/lexer_cocci.mll"
            ( start_line true;
	  TChar(char lexbuf,Ast.IsWchar,get_current_line_type lexbuf) )
# 4245 "parsing_cocci/lexer_cocci.ml"

  | 57 ->
# 1208 "parsing_cocci/lexer_cocci.mll"
             ( start_line true;
	  TString(string lexbuf,Ast.IsWchar,(get_current_line_type lexbuf)) )
# 4251 "parsing_cocci/lexer_cocci.ml"

  | 58 ->
# 1210 "parsing_cocci/lexer_cocci.mll"
            ( start_line true;
	  TChar(char lexbuf,Ast.IsUchar,get_current_line_type lexbuf) )
# 4257 "parsing_cocci/lexer_cocci.ml"

  | 59 ->
# 1212 "parsing_cocci/lexer_cocci.mll"
             ( start_line true;
	  TString(string lexbuf,Ast.IsUchar,(get_current_line_type lexbuf)) )
# 4263 "parsing_cocci/lexer_cocci.ml"

  | 60 ->
# 1214 "parsing_cocci/lexer_cocci.mll"
            ( start_line true;
	  TChar(char lexbuf,Ast.Isuchar,get_current_line_type lexbuf) )
# 4269 "parsing_cocci/lexer_cocci.ml"

  | 61 ->
# 1216 "parsing_cocci/lexer_cocci.mll"
             ( start_line true;
	  TString(string lexbuf,Ast.Isuchar,(get_current_line_type lexbuf)) )
# 4275 "parsing_cocci/lexer_cocci.ml"

  | 62 ->
# 1218 "parsing_cocci/lexer_cocci.mll"
              ( start_line true;
	  TString(string lexbuf,Ast.Isu8char,(get_current_line_type lexbuf)) )
# 4281 "parsing_cocci/lexer_cocci.ml"

  | 63 ->
let
# 1220 "parsing_cocci/lexer_cocci.mll"
             x
# 4287 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 1220 "parsing_cocci/lexer_cocci.mll"
                   ( TFloat(x,(get_current_line_type lexbuf)) )
# 4291 "parsing_cocci/lexer_cocci.ml"

  | 64 ->
let
# 1229 "parsing_cocci/lexer_cocci.mll"
         x
# 4297 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 1229 "parsing_cocci/lexer_cocci.mll"
            ( start_line true; TInt(x,(get_current_line_type lexbuf)) )
# 4301 "parsing_cocci/lexer_cocci.ml"

  | 65 ->
let
# 1231 "parsing_cocci/lexer_cocci.mll"
                           x
# 4307 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 1232 "parsing_cocci/lexer_cocci.mll"
      ( if !Flag.ibm
      then
	begin
	  start_line true;
	  let len = string_of_int(String.length x - 1) in
          TDecimalCst(x,len,"0",(get_current_line_type lexbuf))
	end
      else failwith "unrecognized constant modifier d/D" )
# 4318 "parsing_cocci/lexer_cocci.ml"

  | 66 ->
# 1241 "parsing_cocci/lexer_cocci.mll"
      ( lexerr
	 "metavariables: unrecognised symbol in metavariable_decl_token rule: "
	 (tok lexbuf) )
# 4325 "parsing_cocci/lexer_cocci.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_metavariable_decl_token_rec lexbuf __ocaml_lex_state

and char lexbuf =
   __ocaml_lex_char_rec lexbuf 374
and __ocaml_lex_char_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
let
# 1247 "parsing_cocci/lexer_cocci.mll"
          x
# 4338 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 1247 "parsing_cocci/lexer_cocci.mll"
                                       ( String.make 1 x ^ restchars lexbuf )
# 4342 "parsing_cocci/lexer_cocci.ml"

  | 1 ->
let
# 1249 "parsing_cocci/lexer_cocci.mll"
                                             x
# 4348 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 1249 "parsing_cocci/lexer_cocci.mll"
                                                     ( x ^ restchars lexbuf )
# 4352 "parsing_cocci/lexer_cocci.ml"

  | 2 ->
let
# 1253 "parsing_cocci/lexer_cocci.mll"
                                  x
# 4358 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 1253 "parsing_cocci/lexer_cocci.mll"
                                                     ( x ^ restchars lexbuf )
# 4362 "parsing_cocci/lexer_cocci.ml"

  | 3 ->
let
# 1254 "parsing_cocci/lexer_cocci.mll"
                 v
# 4368 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 1)
and
# 1254 "parsing_cocci/lexer_cocci.mll"
                                  x
# 4373 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 2) in
# 1255 "parsing_cocci/lexer_cocci.mll"
 (
          (match v with (* Machine specific ? *)
          | 'n' -> ()  | 't' -> ()   | 'v' -> ()  | 'b' -> () | 'r' -> ()
          | 'f' -> () | 'a' -> ()
	  | '\\' -> () | '?'  -> () | '\'' -> ()  | '\"' -> ()
          | 'e' -> () (* linuxext: ? *)
	  | _ ->
              Common.pr2 ("LEXER: unrecognised symbol in char:"^tok lexbuf);
	  );
          x ^ restchars lexbuf
	)
# 4387 "parsing_cocci/lexer_cocci.ml"

  | 4 ->
# 1267 "parsing_cocci/lexer_cocci.mll"
      ( Common.pr2 ("LEXER: unrecognised symbol in char:"^tok lexbuf);
        tok lexbuf ^ restchars lexbuf
      )
# 4394 "parsing_cocci/lexer_cocci.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_char_rec lexbuf __ocaml_lex_state

and restchars lexbuf =
   __ocaml_lex_restchars_rec lexbuf 384
and __ocaml_lex_restchars_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 1272 "parsing_cocci/lexer_cocci.mll"
                                       ( "" )
# 4406 "parsing_cocci/lexer_cocci.ml"

  | 1 ->
let
# 1273 "parsing_cocci/lexer_cocci.mll"
          x
# 4412 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 1273 "parsing_cocci/lexer_cocci.mll"
                                       ( String.make 1 x ^ restchars lexbuf )
# 4416 "parsing_cocci/lexer_cocci.ml"

  | 2 ->
let
# 1275 "parsing_cocci/lexer_cocci.mll"
                                             x
# 4422 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 1275 "parsing_cocci/lexer_cocci.mll"
                                                     ( x ^ restchars lexbuf )
# 4426 "parsing_cocci/lexer_cocci.ml"

  | 3 ->
let
# 1279 "parsing_cocci/lexer_cocci.mll"
                                  x
# 4432 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 1279 "parsing_cocci/lexer_cocci.mll"
                                                     ( x ^ restchars lexbuf )
# 4436 "parsing_cocci/lexer_cocci.ml"

  | 4 ->
let
# 1280 "parsing_cocci/lexer_cocci.mll"
                 v
# 4442 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 1)
and
# 1280 "parsing_cocci/lexer_cocci.mll"
                                  x
# 4447 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 2) in
# 1281 "parsing_cocci/lexer_cocci.mll"
 (
          (match v with (* Machine specific ? *)
          | 'n' -> ()  | 't' -> ()   | 'v' -> ()  | 'b' -> () | 'r' -> ()
          | 'f' -> () | 'a' -> ()
	  | '\\' -> () | '?'  -> () | '\'' -> ()  | '\"' -> ()
          | 'e' -> () (* linuxext: ? *)
	  | _ ->
              Common.pr2 ("LEXER: unrecognised symbol in char:"^tok lexbuf);
	  );
          x ^ restchars lexbuf
	)
# 4461 "parsing_cocci/lexer_cocci.ml"

  | 5 ->
# 1293 "parsing_cocci/lexer_cocci.mll"
      ( Common.pr2 ("LEXER: unrecognised symbol in char:"^tok lexbuf);
        tok lexbuf ^ restchars lexbuf
      )
# 4468 "parsing_cocci/lexer_cocci.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_restchars_rec lexbuf __ocaml_lex_state

and string lexbuf =
   __ocaml_lex_string_rec lexbuf 395
and __ocaml_lex_string_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 1298 "parsing_cocci/lexer_cocci.mll"
                                               ( "" )
# 4480 "parsing_cocci/lexer_cocci.ml"

  | 1 ->
let
# 1299 "parsing_cocci/lexer_cocci.mll"
                                 x
# 4486 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 1300 "parsing_cocci/lexer_cocci.mll"
    ( line := !line + 1; (Printf.sprintf "%c" x) ^ string lexbuf )
# 4490 "parsing_cocci/lexer_cocci.ml"

  | 2 ->
let
# 1301 "parsing_cocci/lexer_cocci.mll"
          x
# 4496 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 1301 "parsing_cocci/lexer_cocci.mll"
                               ( Common.string_of_char x ^ string lexbuf )
# 4500 "parsing_cocci/lexer_cocci.ml"

  | 3 ->
let
# 1302 "parsing_cocci/lexer_cocci.mll"
                                            x
# 4506 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 1302 "parsing_cocci/lexer_cocci.mll"
                                              ( x ^ string lexbuf )
# 4510 "parsing_cocci/lexer_cocci.ml"

  | 4 ->
let
# 1303 "parsing_cocci/lexer_cocci.mll"
                               x
# 4516 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 1303 "parsing_cocci/lexer_cocci.mll"
                                              ( x ^ string lexbuf )
# 4520 "parsing_cocci/lexer_cocci.ml"

  | 5 ->
let
# 1304 "parsing_cocci/lexer_cocci.mll"
                v
# 4526 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 1)
and
# 1304 "parsing_cocci/lexer_cocci.mll"
                       x
# 4531 "parsing_cocci/lexer_cocci.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 2) in
# 1305 "parsing_cocci/lexer_cocci.mll"
       (
         (match v with
	    | 'n' -> ()  | 't' -> ()   | 'v' -> ()  | 'b' -> () | 'r' -> ()
	    | 'f' -> () | 'a' -> ()
	    | '\\' -> () | '?'  -> () | '\'' -> ()  | '\"' -> ()
	    | 'e' -> ()
	    | '\n' -> ()
	    | '(' -> () | '|' -> () | ')' -> ()
	    | _ -> lexerr "unrecognised symbol:" (tok lexbuf)
	 );
          x ^ string lexbuf
       )
# 4546 "parsing_cocci/lexer_cocci.ml"

  | 6 ->
# 1317 "parsing_cocci/lexer_cocci.mll"
      ( lexerr "unrecognised symbol: " (tok lexbuf) )
# 4551 "parsing_cocci/lexer_cocci.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_string_rec lexbuf __ocaml_lex_state

and comment check_comment lexbuf =
   __ocaml_lex_comment_rec check_comment lexbuf 407
and __ocaml_lex_comment_rec check_comment lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 1320 "parsing_cocci/lexer_cocci.mll"
         ( let s = tok lexbuf in check_comment s; start_line true; s )
# 4563 "parsing_cocci/lexer_cocci.ml"

  | 1 ->
# 1322 "parsing_cocci/lexer_cocci.mll"
      ( let s = tok lexbuf in
        (* even blank line should have a + *)
        check_comment s;
        reset_line lexbuf; s ^ comment check_comment lexbuf )
# 4571 "parsing_cocci/lexer_cocci.ml"

  | 2 ->
# 1326 "parsing_cocci/lexer_cocci.mll"
        ( pass_zero();
	  if !current_line_started
	  then (start_line true;
		let s = tok lexbuf in s^(comment check_comment lexbuf))
	  else (start_line true; comment check_comment lexbuf) )
# 4580 "parsing_cocci/lexer_cocci.ml"

  | 3 ->
# 1333 "parsing_cocci/lexer_cocci.mll"
      ( let s = tok lexbuf in
        check_comment s; start_line true; s ^ comment check_comment lexbuf )
# 4586 "parsing_cocci/lexer_cocci.ml"

  | 4 ->
# 1336 "parsing_cocci/lexer_cocci.mll"
      ( let s = tok lexbuf in
        check_comment s; start_line true; s ^ comment check_comment lexbuf )
# 4592 "parsing_cocci/lexer_cocci.ml"

  | 5 ->
# 1339 "parsing_cocci/lexer_cocci.mll"
      ( start_line true; let s = tok lexbuf in
        Common.pr2 ("LEXER: unrecognised symbol in comment:"^s);
        s ^ comment check_comment lexbuf
      )
# 4600 "parsing_cocci/lexer_cocci.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_comment_rec check_comment lexbuf __ocaml_lex_state

;;

